import datetime
import math
from typing import Tuple

import numpy as np
import pandas as pd

from sampo.schemas.graph import EdgeType
from sampo.utilities.name_mapper import NameMapper


def get_all_connections(graph_df: pd.DataFrame,
                        use_mapper: bool = False,
                        mapper: NameMapper | None = None) \
        -> Tuple[dict[str, list], dict[str, list]]:

    task_name_column = 'granular_name'

    num_tasks = len(graph_df)
    # Get the upper triangular indices to avoid duplicate pairs
    indices = np.triu_indices(num_tasks, k=1)
    works1_ids = graph_df['activity_id'].values[indices[0]]
    works1_names = graph_df[task_name_column].values[indices[0]]

    works2_ids = graph_df['activity_id'].values[indices[1]]
    works2_names = graph_df[task_name_column].values[indices[1]]

    if use_mapper:
        works1_names = np.vectorize(mapper.get)(works1_names)
        works2_names = np.vectorize(mapper.get)(works2_names)

    return {"ids": works1_ids, "names": works1_names}, {"ids": works2_ids, "names": works2_names}


def get_delta_between_dates(first: str, second: str) -> int:
    return max((datetime.date(int(first.split('-')[0]), int(first.split('-')[1]), int(first.split('-')[2])) -
                datetime.date(int(second.split('-')[0]), int(second.split('-')[1]), int(second.split('-')[2]))).days, 1)


def find_min_without_outliers(lst: list[float]) -> float:
    return round(min([x for x in lst if x >= np.mean(lst) - 3 * np.std(lst)]), 2)


def gather_links_types_statistics(s1: str, f1: str, s2: str, f2: str) \
        -> Tuple[int, int, int, list, list, int, list, list, int, list, list, int, list, list]:
    """
    Count statistics on the occurrence of different mutual arrangement of tasks

    :param s1: start of first work
    :param f1: finish of first work
    :param s2: start of second work
    :param f2: finish of second work
    :return: Statistics on the occurrence of different mutual arrangement of tasks
    """

    fs12, fs21, ss12, ss21 = 0, 0, 0, 0
    ss12_lags, ss12_percent_lags, ss21_lags, ss21_percent_lags = [], [], [], []

    ffs12, ffs21 = 0, 0
    ffs12_lags, ffs12_percent_lags, ffs21_lags, ffs21_percent_lags = [], [], [], []

    if s1 == s2 and f1 == f2:
        ffs12 += 1
        ffs12_percent_lags.append(0.01)
        ffs12_lags.append(0.01)
    if f2 <= s1:
        fs21 += 1
    else:
        if s2 >= f1:
            fs12 += 1
        else:
            if s2 >= s1:
                if f2 >= f1:
                    ffs12 += 1
                    if get_delta_between_dates(f1, s1) != 0:
                        ffs12_percent_lags.append(get_delta_between_dates(s2, s1) / get_delta_between_dates(f1, s1))
                    else:
                        ffs12_percent_lags.append(0)
                    ffs12_lags.append(get_delta_between_dates(s2, s1))
                else:
                    ss12 += 1
                    if get_delta_between_dates(f1, s1) != 0:
                        ss12_percent_lags.append(get_delta_between_dates(s2, s1) / get_delta_between_dates(f1, s1))
                    else:
                        ss12_percent_lags.append(0)
                    ss12_lags.append(get_delta_between_dates(s2, s1))
            else:
                if f2 <= f1:
                    ffs21 += 1
                    if get_delta_between_dates(f2, s2) != 0:
                        ffs21_percent_lags.append(get_delta_between_dates(s1, s2) / get_delta_between_dates(f2, s2))
                    else:
                        ffs21_percent_lags.append(0)
                    ffs21_lags.append(get_delta_between_dates(s1, s2))
                else:
                    ss21 += 1
                    if get_delta_between_dates(f2, s2) != 0:
                        ss21_percent_lags.append(get_delta_between_dates(s1, s2) / get_delta_between_dates(f2, s2))
                    else:
                        ss21_percent_lags.append(0)
                    ss21_lags.append(get_delta_between_dates(s1, s2))
    return fs12, fs21, ss12, ss12_lags, ss12_percent_lags, ss21, ss21_lags, ss21_percent_lags, ffs12, ffs12_lags, ffs12_percent_lags, \
        ffs21, ffs21_lags, ffs21_percent_lags


def get_all_seq_statistic(history_data: pd.DataFrame,
                          graph_df: pd.DataFrame,
                          use_model_name: bool = False,
                          mapper: NameMapper | None = None):
    df_grouped = history_data.copy()

    if use_model_name:
        column_name = 'model_name'
    else:
        if 'granular_name' not in history_data.columns:
            history_data['granular_name'] = [activity_name for activity_name in history_data['work_name']]
        column_name = 'granular_name'

    df_grouped = df_grouped.groupby('upper_works')[column_name].apply(list).reset_index(name="Works")
    works1, works2 = get_all_connections(graph_df, use_model_name, mapper)

    # Declare structure with updated connections

    tasks_names = list(zip(works1['names'], works2['names']))
    tasks_ids = list(zip(works1['ids'], works2['ids']))

    predecessors_info_dict = {w_id: [] for w_id in graph_df['activity_id']}

    if len(tasks_names) != 0:
        for i in range(len(tasks_names)):
            w1, w2 = tasks_names[i]
            w1_id, w2_id = tasks_ids[i]

            if w1 != w2:
                fs12, fs21, ss12, ss21 = 0, 0, 0, 0
                ss12_lags, ss12_percent_lags, ss21_lags, ss21_percent_lags = [], [], [], []

                count = 0

                ffs12, ffs21 = 0, 0
                ffs12_lags, ffs12_percent_lags, ffs21_lags, ffs21_percent_lags = [], [], [], []

                for i, work_list in df_grouped.iterrows():
                    # Looking to see if this pair of works occurred within the same site in the historical data
                    if w1 in work_list['Works'] and w2 in work_list['Works']:
                        ind1 = history_data.loc[(history_data['upper_works'] == work_list['upper_works']) &
                                                (history_data[column_name] == w1)]
                        ind2 = history_data.loc[(history_data['upper_works'] == work_list['upper_works']) &
                                                (history_data[column_name] == w2)]

                        ind1_sorted = ind1.sort_values(by=['first_day', 'last_day']).reset_index(drop=True)
                        ind2_sorted = ind2.sort_values(by=['first_day', 'last_day']).reset_index(drop=True)

                        for l in range(min(len(ind1_sorted), len(ind2_sorted))):
                            s1, f1 = ind1_sorted.loc[l, 'first_day'], ind1_sorted.loc[l, 'last_day']

                            s2, f2 = ind2_sorted.loc[l, 'first_day'], ind2_sorted.loc[l, 'last_day']

                            if not any([type(x) == float for x in [s1, s2, f1, f2]]):
                                tasks_fs12, tasks_fs21, tasks_ss12, tasks_ss12_lags, tasks_ss12_percent_lags, tasks_ss21, tasks_ss21_lags, \
                                    tasks_ss21_percent_lags, tasks_ffs12, tasks_ffs12_lags, tasks_ffs12_percent_lags, tasks_ffs21, tasks_ffs21_lags, tasks_ffs21_percent_lags = gather_links_types_statistics(
                                    s1, f1, s2, f2)

                                count += 1

                                fs12 += tasks_fs12
                                fs21 += tasks_fs21

                                ss12 += tasks_ss12
                                ss12_lags.extend(tasks_ss12_lags)
                                ss12_percent_lags.extend(tasks_ss12_percent_lags)
                                ss21 += tasks_ss21
                                ss21_lags.extend(tasks_ss21_lags)
                                ss21_percent_lags.extend(tasks_ss21_percent_lags)

                                ffs12 += tasks_ffs12
                                ffs12_lags.extend(tasks_ffs12_lags)
                                ffs12_percent_lags.extend(tasks_ffs12_percent_lags)
                                ffs21 += tasks_ffs21
                                ffs21_lags.extend(tasks_ffs21_lags)
                                ffs21_percent_lags.extend(tasks_ffs21_percent_lags)

                if fs12 + ffs12 + ss12 >= fs21 + ffs21 + ss21:
                    order_con = 1
                    fs = fs12
                    ffs = ffs12
                    ss = ss12
                else:
                    order_con = 2
                    fs = fs21
                    ffs = ffs21
                    ss = ss21

                if max([fs, ss, ffs]) != 0:
                    if fs > ss:
                        if ffs > 0:
                            if order_con == 1:
                                predecessors_info_dict[w2_id].append([w1_id, 'FFS',
                                                                      find_min_without_outliers(ffs12_percent_lags),
                                                                      count])
                            else:
                                predecessors_info_dict[w1_id].append([w2_id, 'FFS',
                                                                      find_min_without_outliers(ffs21_percent_lags),
                                                                      count])
                        else:
                            if order_con == 1:
                                predecessors_info_dict[w2_id].append([w1_id, 'FS', 1.0, count])
                            else:
                                predecessors_info_dict[w1_id].append([w2_id, 'FS', 1.0, count])
                    elif ss > ffs:
                        if order_con == 1:
                                predecessors_info_dict[w2_id].append([w1_id, 'SS',
                                                                      find_min_without_outliers(ss12_percent_lags),
                                                                      count])
                        else:
                            predecessors_info_dict[w1_id].append([w2_id, 'SS',
                                                                  find_min_without_outliers(ss21_percent_lags), count])
                    else:
                        if order_con == 1:
                                predecessors_info_dict[w2_id].append([w1_id, 'FFS',
                                                                      find_min_without_outliers(ffs12_percent_lags),
                                                                      count])
                        else:
                            predecessors_info_dict[w1_id].append([w2_id, 'FFS',
                                                                  find_min_without_outliers(ffs21_percent_lags), count])

    return predecessors_info_dict


def set_connections_info(graph_df: pd.DataFrame,
                         history_data: pd.DataFrame,
                         use_model_name: bool = False,
                         mapper: NameMapper | None = None,
                         change_connections_info: bool = False,
                         all_connections: bool = False) \
        -> pd.DataFrame:
    """
    Restore tasks' connection based on history data

    :param: change_connections_info - whether existing connections' information should be modified based on history data
    :param: expert_connections_info - whether existing connections should not be modified based on connection history data
    :return: repaired DataFrame
    """

    def update_connections(pred_ids_lst_tmp, pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst):
        """Updates existing connections with new data."""
        for i, pred_id in enumerate(pred_ids_lst_tmp):
            if pred_id in pred_ids_lst:
                idx = pred_ids_lst.index(pred_id)
                pred_types_lst_tmp[i] = pred_types_lst[idx]
                pred_lags_lst_tmp[i] = pred_lags_lst[idx]
                pred_counts_lst_tmp[i] = pred_counts_lst[idx]
        return pred_ids_lst_tmp, pred_types_lst_tmp, pred_lags_lst_tmp, pred_counts_lst_tmp

    def append_new_connections(pred_ids_lst_tmp, pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst):
        """Appends new connections to the existing lists."""
        for i, pred_id in enumerate(pred_ids_lst):
            if pred_id not in pred_ids_lst_tmp and pred_id != '-1':
                pred_ids_lst_tmp.append(pred_id)
                pred_types_lst_tmp.append(pred_types_lst[i])
                pred_lags_lst_tmp.append(pred_lags_lst[i])
                pred_counts_lst_tmp.append(pred_counts_lst[i])
        return pred_ids_lst_tmp, pred_types_lst_tmp, pred_lags_lst_tmp, pred_counts_lst_tmp

    tasks_df = graph_df.copy().set_index('activity_id', drop=False)

    # | ------ no changes ------- |
    if not change_connections_info and all_connections:
        tasks_df['counts'] = [[0] * len(tasks_df['predecessor_ids'][i]) for i in range(tasks_df.shape[0])]

        tasks_df['connection_types'] = tasks_df['connection_types'].apply(
            lambda x: [EdgeType(elem) if elem != '-1' else EdgeType.FinishStart for elem in x]
        )
        return tasks_df

    # | ----------- for cache data ----------- |
    # connections_dict = get_all_seq_statistic(history_data, graph_df, use_model_name, mapper)
    # with open('dormitory.json', 'w') as f:
    #     json.dump(connections_dict, f)

    # | ----------- cached data -------------- |
    gas_network = {"25809398": [], "25809830": [], "25809831": [["25809830", "FFS", 0.01, 76], ["25809850", "FS", 1.0, 2], ["25809853", "FS", 1.0, 2], ["25809855", "FS", 1.0, 4]], "25809833": [["25809830", "FFS", 0.01, 263], ["25809831", "FFS", 0.01, 527]], "25813507": [["25809830", "FFS", 0.01, 57], ["25809831", "FFS", 0.01, 196], ["25809833", "FFS", 0.01, 312], ["25809852", "FS", 1.0, 1], ["25809854", "FS", 1.0, 1]], "25809836": [["25809830", "FFS", 0.01, 104], ["25809831", "FFS", 0.01, 247], ["25809833", "FFS", 0.01, 1235], ["25813507", "FFS", 0.01, 205]], "25809832": [["25809830", "FS", 1.0, 2], ["25809831", "FFS", 0.01, 2], ["25809833", "FFS", 0.01, 3], ["25809836", "FFS", 0.01, 3], ["25809839", "SS", 0.45, 4], ["25809842", "FFS", 0.5, 29], ["25809843", "SS", 0.08, 13]], "25809837": [["25809831", "FS", 1.0, 2], ["25809836", "SS", 0.75, 2], ["25809835", "FS", 1.0, 2], ["25809847", "FS", 1.0, 1]], "25809838": [["25809830", "FS", 1.0, 1], ["25809831", "FFS", 0.13, 92], ["25809833", "FFS", 0.01, 376], ["25813507", "FFS", 0.01, 89], ["25809836", "FFS", 0.01, 447]], "25809839": [["25809830", "FFS", 0.52, 21], ["25809831", "FFS", 0.01, 60], ["25809833", "FFS", 0.01, 381], ["25813507", "FFS", 0.33, 27], ["25809836", "FFS", 0.01, 444], ["25809838", "FFS", 0.01, 329], ["25809835", "FS", 1.0, 2], ["25809847", "FFS", 0.02, 65], ["25809850", "FS", 1.0, 1], ["25809852", "FFS", 0.05, 282], ["25809848", "FFS", 0.27, 9], ["25809853", "FS", 1.0, 1], ["25809854", "FFS", 0.05, 282], ["25809855", "FS", 1.0, 5]], "25809834": [["25809831", "FFS", 0.01, 17], ["25809833", "FS", 1.0, 10], ["25809836", "FS", 1.0, 11], ["25809838", "FFS", 0.5, 9], ["25809839", "FS", 1.0, 5], ["25809835", "FS", 1.0, 5], ["25809841", "FFS", 0.86, 12], ["25809847", "FS", 1.0, 7], ["25809848", "FS", 1.0, 3]], "25809835": [["25809831", "FFS", 0.01, 21], ["25809833", "SS", 0.25, 5], ["25809836", "SS", 0.19, 2], ["25809838", "SS", 0.5, 5], ["25809841", "SS", 0.76, 1], ["25809847", "FS", 1.0, 1], ["25809852", "FS", 1.0, 6], ["25809854", "FS", 1.0, 6]], "25809842": [["25809830", "FFS", 0.01, 6], ["25809831", "FFS", 0.01, 5], ["25809833", "FFS", 0.01, 8], ["25809836", "FFS", 0.01, 9], ["25809839", "FFS", 0.01, 2], ["25809840", "SS", 0.79, 1], ["25809841", "FS", 1.0, 11]], "25809843": [["25809842", "FFS", 0.06, 1]], "25809844": [["25809832", "FFS", 0.01, 4], ["25809843", "SS", 0.03, 4], ["25809841", "FS", 1.0, 1]], "25809840": [["25809830", "FS", 1.0, 2], ["25809831", "FFS", 0.01, 37], ["25809833", "FFS", 0.01, 43], ["25809836", "FFS", 0.17, 45], ["25809838", "FS", 1.0, 8], ["25809839", "FS", 1.0, 13], ["25809834", "FFS", 0.01, 22], ["25809835", "FFS", 0.01, 24], ["25809841", "FS", 1.0, 18], ["25809847", "FS", 1.0, 2], ["25809850", "FFS", 0.12, 1], ["25809848", "FS", 1.0, 7], ["25809853", "FFS", 0.12, 1], ["25809855", "SS", 0.09, 1]], "25809841": [["25809830", "FFS", 0.01, 180], ["25809831", "FFS", 0.01, 49], ["25809833", "FFS", 0.01, 368], ["25813507", "FFS", 0.01, 77], ["25809836", "FFS", 0.01, 322], ["25809832", "SS", 0.32, 7], ["25809838", "FFS", 0.01, 87], ["25809839", "FFS", 0.01, 177], ["25809847", "FFS", 0.2, 80], ["25809850", "FS", 1.0, 2], ["25809852", "FFS", 0.2, 12], ["25809848", "FS", 1.0, 17], ["25809853", "FS", 1.0, 2], ["25809854", "FFS", 0.2, 12]], "25809399": [], "25809400": [], "25809847": [["25809830", "FS", 1.0, 3], ["25809831", "FFS", 0.01, 187], ["25809833", "FFS", 0.01, 347], ["25813507", "FFS", 0.01, 67], ["25809836", "FFS", 0.01, 338], ["25809832", "FS", 1.0, 1], ["25809838", "FFS", 0.01, 50], ["25809850", "FS", 1.0, 6], ["25809852", "FFS", 0.05, 339], ["25809853", "FS", 1.0, 6], ["25809854", "FFS", 0.05, 339]], "25809850": [["25809833", "FS", 1.0, 3], ["25809836", "FFS", 0.67, 6], ["25809838", "FFS", 0.03, 43]], "25809852": [["25809830", "FS", 1.0, 1], ["25809831", "FFS", 0.01, 7], ["25809833", "FFS", 0.01, 26], ["25809836", "FFS", 0.46, 24], ["25809838", "FFS", 0.5, 14], ["25809834", "FFS", 0.01, 3], ["25809842", "FFS", 0.01, 2], ["25809840", "SS", 0.01, 2], ["25809850", "FFS", 0.01, 306], ["25809856", "FS", 1.0, 5]], "25809848": [["25809830", "FS", 1.0, 1], ["25809833", "FFS", 0.01, 85], ["25809836", "FFS", 0.01, 133], ["25809838", "FFS", 0.01, 53], ["25809847", "FFS", 0.07, 9], ["25809850", "FFS", 0.01, 68], ["25809852", "FFS", 0.01, 53], ["25809853", "FFS", 0.03, 68], ["25809856", "FS", 1.0, 1]], "25809853": [["25809833", "FS", 1.0, 3], ["25809836", "FFS", 0.67, 6], ["25809838", "FFS", 0.03, 43], ["25809852", "FFS", 0.01, 306]], "25809854": [["25809830", "FS", 1.0, 1], ["25809831", "FFS", 0.01, 7], ["25809833", "FFS", 0.01, 26], ["25809836", "FFS", 0.46, 24], ["25809838", "FFS", 0.5, 14], ["25809834", "FFS", 0.01, 3], ["25809842", "FFS", 0.01, 2], ["25809840", "SS", 0.01, 2], ["25809850", "FFS", 0.01, 306], ["25809848", "FFS", 0.01, 53], ["25809853", "FFS", 0.01, 306], ["25809856", "FS", 1.0, 5]], "25809856": [["25809830", "FS", 1.0, 2], ["25809831", "FFS", 0.01, 38], ["25809833", "FFS", 0.01, 40], ["25813507", "FS", 1.0, 21], ["25809836", "FFS", 0.01, 42], ["25809839", "FFS", 0.01, 21], ["25809834", "FS", 1.0, 2], ["25809840", "FS", 1.0, 1], ["25809841", "FS", 1.0, 10], ["25809847", "FS", 1.0, 41]], "25809401": [], "25809402": [], "25809857": [["25809847", "FS", 1.0, 1], ["25809852", "FS", 1.0, 1], ["25809854", "FS", 1.0, 1], ["25809855", "FS", 1.0, 1]], "25809858": [["25809836", "FS", 1.0, 1], ["25809838", "FS", 1.0, 1], ["25809839", "FFS", 0.01, 56], ["25809841", "SS", 0.36, 4], ["25809847", "FS", 1.0, 4], ["25809850", "FFS", 0.93, 91], ["25809852", "FFS", 0.01, 378], ["25809848", "FFS", 0.01, 17], ["25809853", "FFS", 0.93, 91], ["25809854", "FFS", 0.01, 378], ["25809855", "FFS", 0.96, 97]], "25809855": [["25809833", "FS", 1.0, 1], ["25809838", "FFS", 0.89, 4], ["25809841", "SS", 0.03, 2], ["25809847", "FFS", 0.56, 20], ["25809850", "FFS", 0.01, 190], ["25809852", "FFS", 0.01, 291], ["25809848", "FFS", 0.85, 11], ["25809853", "FFS", 0.01, 190], ["25809854", "FFS", 0.01, 291]], "25809403": []}
    electroline = {"223084": [["223094", "FS", 1.0, 1]], "223085": [["223084", "FFS", 0.01, 1602]], "223086": [["223084", "FFS", 0.01, 900], ["223085", "FFS", 0.01, 1235]], "223087": [["223084", "FFS", 0.01, 173], ["223085", "FFS", 0.01, 347], ["223086", "FFS", 0.01, 338]], "223088": [["223084", "FFS", 0.09, 18], ["223085", "FFS", 0.08, 32], ["223086", "FFS", 0.01, 38], ["223087", "FFS", 0.01, 52], ["223089", "FFS", 0.08, 52]], "223089": [["223084", "FFS", 0.01, 173], ["223085", "FFS", 0.01, 347], ["223086", "FFS", 0.01, 338]], "223092": [["223084", "FS", 1.0, 5], ["223085", "FFS", 0.5, 6], ["223086", "FFS", 0.36, 6], ["223087", "FFS", 0.36, 7], ["223089", "FFS", 0.36, 7]], "223093": [["223084", "FS", 1.0, 1], ["223085", "FS", 1.0, 1], ["223086", "FS", 1.0, 1], ["223087", "FS", 1.0, 2], ["223089", "FS", 1.0, 2], ["223092", "SS", 0.04, 62]], "223094": [["223085", "FS", 1.0, 25], ["223086", "FFS", 0.47, 28], ["223087", "FFS", 0.69, 39], ["223088", "FFS", 0.75, 8], ["223089", "FFS", 0.69, 39], ["223092", "FFS", 0.01, 14], ["223093", "FFS", 0.07, 9]], "223095": [["223084", "FFS", 0.01, 11], ["223085", "FFS", 0.01, 40], ["223086", "FFS", 0.01, 42], ["223087", "FS", 1.0, 41], ["223088", "FFS", 0.75, 10], ["223089", "FS", 1.0, 41], ["223092", "FFS", 0.01, 58], ["223093", "FFS", 0.01, 39], ["223094", "FFS", 0.01, 58]]}
    dormitory = {"6162582": [], "6166292": [["6166293", "FS", 1.0, 3], ["6166294", "FS", 1.0, 3], ["6166297", "FS", 1.0, 4], ["6166298", "FS", 1.0, 4], ["6166300", "SS", 0.33, 2], ["6166301", "FS", 1.0, 4], ["6166302", "FS", 1.0, 2], ["6166303", "FS", 1.0, 4], ["6166305", "FS", 1.0, 4], ["6166309", "FS", 1.0, 4], ["6166322", "FS", 1.0, 4], ["6166336", "FS", 1.0, 4], ["6166337", "FS", 1.0, 4], ["6166338", "FS", 1.0, 4], ["6166339", "FS", 1.0, 4], ["6166340", "FS", 1.0, 4], ["6166341", "FS", 1.0, 4], ["6166342", "FS", 1.0, 4], ["6166343", "FS", 1.0, 4], ["6166344", "FS", 1.0, 4], ["6166345", "FS", 1.0, 4], ["6166346", "FS", 1.0, 4], ["6166347", "FS", 1.0, 4], ["6166351", "SS", 0.33, 2], ["6166352", "SS", 0.33, 2], ["6166356", "SS", 0.33, 2]], "6166293": [["6166297", "FFS", 0.17, 19], ["6166298", "FFS", 0.17, 19], ["6166299", "FS", 1.0, 2], ["6166301", "FFS", 0.17, 19], ["6166302", "FS", 1.0, 3], ["6166303", "FFS", 0.17, 19], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.17, 19], ["6166309", "FFS", 0.17, 19], ["6166316", "FS", 1.0, 2], ["6166319", "FS", 1.0, 2], ["6166322", "FFS", 0.17, 19], ["6166332", "FS", 1.0, 2], ["6166333", "FS", 1.0, 2], ["6166335", "FS", 1.0, 2], ["6166336", "FFS", 0.17, 19], ["6166337", "FFS", 0.17, 19], ["6166338", "FFS", 0.17, 19], ["6166339", "FFS", 0.17, 19], ["6166340", "FFS", 0.17, 19], ["6166341", "FFS", 0.17, 19], ["6166342", "FFS", 0.17, 19], ["6166343", "FFS", 0.17, 19], ["6166344", "FFS", 0.17, 19], ["6166345", "FFS", 0.17, 19], ["6166346", "FFS", 0.17, 19], ["6166347", "FFS", 0.17, 19], ["6166360", "FS", 1.0, 2], ["6166362", "FS", 1.0, 2], ["6166398", "FS", 1.0, 2], ["6166399", "FS", 1.0, 2], ["6166402", "FS", 1.0, 2]], "6166294": [["6166297", "FFS", 0.17, 19], ["6166298", "FFS", 0.17, 19], ["6166299", "FS", 1.0, 2], ["6166301", "FFS", 0.17, 19], ["6166302", "FS", 1.0, 3], ["6166303", "FFS", 0.17, 19], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.17, 19], ["6166309", "FFS", 0.17, 19], ["6166316", "FS", 1.0, 2], ["6166319", "FS", 1.0, 2], ["6166322", "FFS", 0.17, 19], ["6166332", "FS", 1.0, 2], ["6166333", "FS", 1.0, 2], ["6166335", "FS", 1.0, 2], ["6166336", "FFS", 0.17, 19], ["6166337", "FFS", 0.17, 19], ["6166338", "FFS", 0.17, 19], ["6166339", "FFS", 0.17, 19], ["6166340", "FFS", 0.17, 19], ["6166341", "FFS", 0.17, 19], ["6166342", "FFS", 0.17, 19], ["6166343", "FFS", 0.17, 19], ["6166344", "FFS", 0.17, 19], ["6166345", "FFS", 0.17, 19], ["6166346", "FFS", 0.17, 19], ["6166347", "FFS", 0.17, 19], ["6166360", "FS", 1.0, 2], ["6166362", "FS", 1.0, 2], ["6166398", "FS", 1.0, 2], ["6166399", "FS", 1.0, 2], ["6166402", "FS", 1.0, 2]], "6166295": [["6166292", "SS", 0.66, 2], ["6166293", "FFS", 0.01, 8], ["6166294", "FFS", 0.01, 8], ["6166308", "FS", 1.0, 1], ["6166397", "FFS", 0.62, 3], ["6166411", "FFS", 0.33, 2], ["6166422", "FFS", 0.09, 14], ["6166425", "FFS", 0.62, 3], ["6166426", "FFS", 0.62, 3], ["6166432", "FFS", 0.69, 34], ["6166434", "FS", 1.0, 32], ["6166435", "FS", 1.0, 5], ["16147477", "SS", 0.66, 2], ["16345501", "FFS", 0.33, 2], ["16345502", "FFS", 0.33, 2], ["16345503", "FFS", 0.33, 2], ["16345504", "FFS", 0.33, 2], ["16345505", "FFS", 0.33, 2], ["16345506", "FFS", 0.33, 2], ["17663819", "FFS", 0.33, 2], ["17663847", "FFS", 0.33, 2]], "6166296": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166299", "FS", 1.0, 2], ["6166300", "FS", 1.0, 18], ["6166304", "FS", 1.0, 1], ["6166308", "FS", 1.0, 1], ["6166316", "FFS", 0.1, 102], ["6166319", "FFS", 0.1, 102], ["6166332", "FFS", 0.1, 102], ["6166333", "FFS", 0.1, 102], ["6166335", "FFS", 0.1, 102], ["6166351", "FS", 1.0, 18], ["6166352", "FS", 1.0, 18], ["6166353", "FFS", 0.16, 48], ["6166356", "FS", 1.0, 18], ["6166390", "FS", 1.0, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166400", "FS", 1.0, 37], ["6166407", "FS", 1.0, 1], ["6166411", "FFS", 0.88, 12], ["6166424", "FFS", 0.11, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FS", 1.0, 5], ["6166434", "FS", 1.0, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "6166297": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166298": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166299": [["6166295", "FFS", 0.01, 3], ["6166297", "FFS", 0.01, 6], ["6166298", "FFS", 0.01, 6], ["6166301", "FS", 1.0, 6], ["6166303", "FS", 1.0, 6], ["6166305", "FS", 1.0, 6], ["6166309", "FS", 1.0, 6], ["6166322", "FS", 1.0, 6], ["6166334", "FS", 1.0, 1], ["6166336", "FS", 1.0, 6], ["6166337", "FS", 1.0, 6], ["6166338", "FS", 1.0, 6], ["6166339", "FS", 1.0, 6], ["6166340", "FS", 1.0, 6], ["6166341", "FS", 1.0, 6], ["6166342", "FS", 1.0, 6], ["6166343", "FS", 1.0, 6], ["6166344", "FS", 1.0, 6], ["6166345", "FS", 1.0, 6], ["6166346", "FS", 1.0, 6], ["6166347", "FS", 1.0, 6], ["6166353", "FS", 1.0, 1], ["6166360", "FS", 1.0, 1], ["6166362", "FS", 1.0, 1], ["6166398", "FS", 1.0, 1], ["6166399", "FS", 1.0, 1], ["6166402", "FS", 1.0, 1], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1]], "6166300": [["6166293", "FS", 1.0, 3], ["6166294", "FS", 1.0, 3], ["6166295", "FFS", 0.01, 5], ["6166297", "FFS", 0.01, 25], ["6166298", "FFS", 0.01, 25], ["6166299", "FFS", 0.01, 5], ["6166301", "FS", 1.0, 25], ["6166303", "FS", 1.0, 25], ["6166305", "FS", 1.0, 25], ["6166309", "FS", 1.0, 25], ["6166316", "FS", 1.0, 1], ["6166319", "FS", 1.0, 1], ["6166322", "FS", 1.0, 25], ["6166332", "FS", 1.0, 1], ["6166333", "FS", 1.0, 1], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 1], ["6166336", "FS", 1.0, 25], ["6166337", "FS", 1.0, 25], ["6166338", "FS", 1.0, 25], ["6166339", "FS", 1.0, 25], ["6166340", "FS", 1.0, 25], ["6166341", "FS", 1.0, 25], ["6166342", "FS", 1.0, 25], ["6166343", "FS", 1.0, 25], ["6166344", "FS", 1.0, 25], ["6166345", "FS", 1.0, 25], ["6166346", "FS", 1.0, 25], ["6166347", "FS", 1.0, 25], ["6166360", "FS", 1.0, 1], ["6166362", "FS", 1.0, 1], ["6166390", "FS", 1.0, 5], ["6166398", "FS", 1.0, 1], ["6166399", "FS", 1.0, 1], ["6166400", "FS", 1.0, 5], ["6166402", "FS", 1.0, 1], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["16147472", "FFS", 0.94, 35], ["16147473", "FFS", 0.94, 35]], "6166301": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166302": [["6166295", "FFS", 0.01, 3], ["6166296", "FFS", 0.01, 3], ["6166297", "FFS", 0.01, 5], ["6166298", "FFS", 0.01, 5], ["6166299", "FFS", 0.01, 2], ["6166300", "FFS", 0.01, 2], ["6166301", "FFS", 0.01, 5], ["6166303", "FFS", 0.96, 5], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.96, 5], ["6166309", "FFS", 0.96, 5], ["6166316", "FS", 1.0, 2], ["6166319", "FS", 1.0, 2], ["6166322", "FFS", 0.96, 5], ["6166332", "FS", 1.0, 2], ["6166333", "FS", 1.0, 2], ["6166335", "FS", 1.0, 2], ["6166336", "FFS", 0.96, 5], ["6166337", "FFS", 0.96, 5], ["6166338", "FFS", 0.96, 5], ["6166339", "FFS", 0.96, 5], ["6166340", "FFS", 0.96, 5], ["6166341", "FFS", 0.96, 5], ["6166342", "FFS", 0.96, 5], ["6166343", "FFS", 0.96, 5], ["6166344", "FFS", 0.96, 5], ["6166345", "FFS", 0.96, 5], ["6166346", "FFS", 0.96, 5], ["6166347", "FFS", 0.96, 5], ["6166351", "FS", 1.0, 2], ["6166352", "FS", 1.0, 2], ["6166356", "FS", 1.0, 2], ["16147472", "FS", 1.0, 2], ["16147473", "FS", 1.0, 2]], "6166303": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166304": [["6166295", "FFS", 0.01, 1], ["6166297", "SS", 0.96, 1], ["6166298", "SS", 0.96, 1], ["6166299", "FFS", 0.01, 1], ["6166300", "FFS", 0.01, 1], ["6166301", "SS", 0.96, 1], ["6166303", "SS", 0.96, 1], ["6166305", "SS", 0.96, 1], ["6166309", "SS", 0.96, 1], ["6166322", "SS", 0.96, 1], ["6166336", "SS", 0.96, 1], ["6166337", "SS", 0.96, 1], ["6166338", "SS", 0.96, 1], ["6166339", "SS", 0.96, 1], ["6166340", "SS", 0.96, 1], ["6166341", "SS", 0.96, 1], ["6166342", "SS", 0.96, 1], ["6166343", "SS", 0.96, 1], ["6166344", "SS", 0.96, 1], ["6166345", "SS", 0.96, 1], ["6166346", "SS", 0.96, 1], ["6166347", "SS", 0.96, 1]], "6166305": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166306": [["6166292", "FS", 1.0, 1], ["6166293", "FS", 1.0, 1], ["6166294", "FS", 1.0, 1], ["6166295", "FS", 1.0, 1], ["6166296", "FS", 1.0, 1], ["6166297", "FS", 1.0, 2], ["6166298", "FS", 1.0, 2], ["6166301", "FS", 1.0, 2], ["6166302", "FS", 1.0, 1], ["6166303", "FS", 1.0, 2], ["6166305", "FS", 1.0, 2], ["6166307", "FS", 1.0, 1], ["6166309", "FS", 1.0, 2], ["6166322", "FS", 1.0, 2], ["6166323", "FS", 1.0, 1], ["6166336", "FS", 1.0, 2], ["6166337", "FS", 1.0, 2], ["6166338", "FS", 1.0, 2], ["6166339", "FS", 1.0, 2], ["6166340", "FS", 1.0, 2], ["6166341", "FS", 1.0, 2], ["6166342", "FS", 1.0, 2], ["6166343", "FS", 1.0, 2], ["6166344", "FS", 1.0, 2], ["6166345", "FS", 1.0, 2], ["6166346", "FS", 1.0, 2], ["6166347", "FS", 1.0, 2], ["6166368", "FS", 1.0, 1], ["6166369", "FS", 1.0, 1], ["6166390", "FS", 1.0, 1], ["6166400", "FS", 1.0, 1], ["8867825", "FFS", 0.57, 1], ["15643783", "FS", 1.0, 1], ["15643796", "FS", 1.0, 1], ["15659698", "FS", 1.0, 1], ["15659699", "FS", 1.0, 1], ["15659700", "FS", 1.0, 1], ["16147472", "FS", 1.0, 1], ["16147473", "FS", 1.0, 1], ["16147477", "FS", 1.0, 1], ["17502541", "FS", 1.0, 1], ["17502543", "FS", 1.0, 1], ["17502545", "FS", 1.0, 1]], "6166307": [["6166297", "FFS", 0.01, 2], ["6166298", "FFS", 0.01, 2], ["6166299", "FFS", 0.01, 1], ["6166300", "FFS", 0.01, 1], ["6166301", "FFS", 0.01, 2], ["6166303", "FFS", 0.01, 2], ["6166305", "FFS", 0.01, 2], ["6166309", "FS", 1.0, 2], ["6166322", "FS", 1.0, 2], ["6166336", "FS", 1.0, 2], ["6166337", "FS", 1.0, 2], ["6166338", "FS", 1.0, 2], ["6166339", "FS", 1.0, 2], ["6166340", "FS", 1.0, 2], ["6166341", "FS", 1.0, 2], ["6166342", "FS", 1.0, 2], ["6166343", "FS", 1.0, 2], ["6166344", "FS", 1.0, 2], ["6166345", "FS", 1.0, 2], ["6166346", "FS", 1.0, 2], ["6166347", "FS", 1.0, 2], ["16147472", "FS", 1.0, 1], ["16147473", "FS", 1.0, 1]], "6166308": [["6166292", "FS", 1.0, 2], ["6166293", "FFS", 0.01, 3], ["6166294", "FFS", 0.01, 3], ["6166297", "FS", 1.0, 3], ["6166298", "FS", 1.0, 3], ["6166301", "FS", 1.0, 3], ["6166302", "FS", 1.0, 2], ["6166303", "FS", 1.0, 3], ["6166305", "FS", 1.0, 3], ["6166306", "SS", 0.63, 2], ["6166307", "FS", 1.0, 1], ["6166309", "FS", 1.0, 3], ["6166322", "FS", 1.0, 3], ["6166336", "FS", 1.0, 3], ["6166337", "FS", 1.0, 3], ["6166338", "FS", 1.0, 3], ["6166339", "FS", 1.0, 3], ["6166340", "FS", 1.0, 3], ["6166341", "FS", 1.0, 3], ["6166342", "FS", 1.0, 3], ["6166343", "FS", 1.0, 3], ["6166344", "FS", 1.0, 3], ["6166345", "FS", 1.0, 3], ["6166346", "FS", 1.0, 3], ["6166347", "FS", 1.0, 3], ["8867825", "FS", 1.0, 1], ["16147472", "FFS", 0.14, 3], ["16147473", "FFS", 0.14, 3], ["16147477", "FS", 1.0, 2]], "6166309": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166316": [["6166295", "FFS", 0.01, 44], ["6166297", "FFS", 0.01, 57], ["6166298", "FFS", 0.01, 57], ["6166301", "FFS", 0.01, 57], ["6166303", "FFS", 0.01, 57], ["6166305", "FFS", 0.01, 57], ["6166309", "FFS", 0.01, 57], ["6166321", "FS", 1.0, 1], ["6166390", "FFS", 0.4, 44], ["6166391", "FFS", 0.23, 3], ["6166400", "FFS", 0.4, 44], ["6166432", "FFS", 0.46, 24], ["6166433", "FS", 1.0, 2], ["6166434", "FFS", 0.68, 26], ["6166435", "FS", 1.0, 1]], "6166319": [["6166295", "FFS", 0.01, 44], ["6166297", "FFS", 0.01, 57], ["6166298", "FFS", 0.01, 57], ["6166301", "FFS", 0.01, 57], ["6166303", "FFS", 0.01, 57], ["6166305", "FFS", 0.01, 57], ["6166309", "FFS", 0.01, 57], ["6166321", "FS", 1.0, 1], ["6166390", "FFS", 0.4, 44], ["6166391", "FFS", 0.23, 3], ["6166400", "FFS", 0.4, 44], ["6166432", "FFS", 0.46, 24], ["6166433", "FS", 1.0, 2], ["6166434", "FFS", 0.68, 26], ["6166435", "FS", 1.0, 1]], "6166321": [["6166296", "FS", 1.0, 2], ["6166297", "FFS", 0.01, 2], ["6166298", "FFS", 0.01, 2], ["6166301", "FFS", 0.01, 2], ["6166303", "FFS", 0.01, 2], ["6166305", "FFS", 0.01, 2], ["6166309", "FFS", 0.01, 2], ["6166322", "FS", 1.0, 2], ["6166323", "FS", 1.0, 2], ["6166336", "FS", 1.0, 2], ["6166337", "FS", 1.0, 2], ["6166338", "FS", 1.0, 2], ["6166339", "FS", 1.0, 2], ["6166340", "FS", 1.0, 2], ["6166341", "FS", 1.0, 2], ["6166342", "FS", 1.0, 2], ["6166343", "FS", 1.0, 2], ["6166344", "FS", 1.0, 2], ["6166345", "FS", 1.0, 2], ["6166346", "FS", 1.0, 2], ["6166347", "FS", 1.0, 2], ["6166368", "FS", 1.0, 2], ["6166369", "FS", 1.0, 2], ["15643783", "FS", 1.0, 2], ["15643796", "FS", 1.0, 2], ["15659698", "FS", 1.0, 2], ["15659699", "FS", 1.0, 2], ["15659700", "FS", 1.0, 2], ["17502541", "FS", 1.0, 2], ["17502543", "FS", 1.0, 2], ["17502545", "FS", 1.0, 2]], "6166322": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166323": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.1, 102], ["6166333", "FFS", 0.1, 102], ["6166335", "FFS", 0.1, 102], ["6166351", "FS", 1.0, 18], ["6166352", "FS", 1.0, 18], ["6166353", "FFS", 0.16, 48], ["6166356", "FS", 1.0, 18], ["6166390", "FS", 1.0, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166400", "FS", 1.0, 37], ["6166407", "FS", 1.0, 1], ["6166411", "FFS", 0.88, 12], ["6166424", "FFS", 0.11, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FS", 1.0, 5], ["6166434", "FS", 1.0, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "6166324": [["6166316", "FFS", 0.5, 1], ["6166319", "FFS", 0.5, 1], ["6166332", "FFS", 0.5, 1], ["6166333", "FFS", 0.5, 1], ["6166335", "FFS", 0.5, 1], ["6166353", "FS", 1.0, 1]], "6166325": [["6166296", "FS", 1.0, 4], ["6166316", "FFS", 0.01, 17], ["6166319", "FFS", 0.01, 17], ["6166323", "FS", 1.0, 4], ["6166324", "SS", 0.08, 3], ["6166332", "FFS", 0.5, 17], ["6166333", "FFS", 0.5, 17], ["6166335", "FFS", 0.5, 17], ["6166360", "FS", 1.0, 1], ["6166362", "FS", 1.0, 1], ["6166368", "FS", 1.0, 4], ["6166369", "FS", 1.0, 4], ["6166398", "FS", 1.0, 1], ["6166399", "FS", 1.0, 1], ["6166402", "FS", 1.0, 1], ["15643783", "FS", 1.0, 4], ["15643796", "FS", 1.0, 4], ["15659698", "FS", 1.0, 4], ["15659699", "FS", 1.0, 4], ["15659700", "FS", 1.0, 4], ["17502541", "FS", 1.0, 4], ["17502543", "FS", 1.0, 4], ["17502545", "FS", 1.0, 4]], "6166329": [["6166296", "FS", 1.0, 4], ["6166316", "FFS", 0.01, 17], ["6166319", "FFS", 0.01, 17], ["6166323", "FS", 1.0, 4], ["6166324", "SS", 0.08, 3], ["6166332", "FFS", 0.5, 17], ["6166333", "FFS", 0.5, 17], ["6166335", "FFS", 0.5, 17], ["6166360", "FS", 1.0, 1], ["6166362", "FS", 1.0, 1], ["6166368", "FS", 1.0, 4], ["6166369", "FS", 1.0, 4], ["6166398", "FS", 1.0, 1], ["6166399", "FS", 1.0, 1], ["6166402", "FS", 1.0, 1], ["15643783", "FS", 1.0, 4], ["15643796", "FS", 1.0, 4], ["15659698", "FS", 1.0, 4], ["15659699", "FS", 1.0, 4], ["15659700", "FS", 1.0, 4], ["17502541", "FS", 1.0, 4], ["17502543", "FS", 1.0, 4], ["17502545", "FS", 1.0, 4]], "6166332": [["6166295", "FFS", 0.01, 44], ["6166297", "FFS", 0.01, 57], ["6166298", "FFS", 0.01, 57], ["6166301", "FFS", 0.01, 57], ["6166303", "FFS", 0.01, 57], ["6166305", "FFS", 0.01, 57], ["6166309", "FFS", 0.01, 57], ["6166321", "FS", 1.0, 1], ["6166322", "FFS", 0.01, 57], ["6166390", "FFS", 0.4, 44], ["6166391", "FFS", 0.23, 3], ["6166400", "FFS", 0.4, 44], ["6166432", "FFS", 0.46, 24], ["6166433", "FS", 1.0, 2], ["6166434", "FFS", 0.68, 26], ["6166435", "FS", 1.0, 1]], "6166333": [["6166295", "FFS", 0.01, 44], ["6166297", "FFS", 0.01, 57], ["6166298", "FFS", 0.01, 57], ["6166301", "FFS", 0.01, 57], ["6166303", "FFS", 0.01, 57], ["6166305", "FFS", 0.01, 57], ["6166309", "FFS", 0.01, 57], ["6166321", "FS", 1.0, 1], ["6166322", "FFS", 0.01, 57], ["6166390", "FFS", 0.4, 44], ["6166391", "FFS", 0.23, 3], ["6166400", "FFS", 0.4, 44], ["6166432", "FFS", 0.46, 24], ["6166433", "FS", 1.0, 2], ["6166434", "FFS", 0.68, 26], ["6166435", "FS", 1.0, 1]], "6166334": [["6166295", "SS", 0.89, 3], ["6166296", "FS", 1.0, 2], ["6166297", "SS", 0.52, 6], ["6166298", "SS", 0.52, 6], ["6166301", "SS", 0.52, 6], ["6166303", "SS", 0.52, 6], ["6166305", "SS", 0.52, 6], ["6166309", "SS", 0.52, 6], ["6166316", "FFS", 0.56, 5], ["6166319", "FFS", 0.56, 5], ["6166322", "SS", 0.52, 6], ["6166323", "FS", 1.0, 2], ["6166332", "FFS", 0.56, 5], ["6166333", "FFS", 0.56, 5], ["6166335", "FFS", 0.56, 5], ["6166390", "SS", 0.89, 3], ["6166397", "FS", 1.0, 1], ["6166400", "SS", 0.89, 3], ["6166404", "FS", 1.0, 1], ["6166408", "FFS", 0.73, 2], ["6166411", "FS", 1.0, 2], ["6166424", "FS", 1.0, 2], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166434", "FS", 1.0, 4], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166335": [["6166295", "FFS", 0.01, 44], ["6166297", "FFS", 0.01, 57], ["6166298", "FFS", 0.01, 57], ["6166301", "FFS", 0.01, 57], ["6166303", "FFS", 0.01, 57], ["6166305", "FFS", 0.01, 57], ["6166309", "FFS", 0.01, 57], ["6166321", "FS", 1.0, 1], ["6166322", "FFS", 0.01, 57], ["6166390", "FFS", 0.4, 44], ["6166391", "FFS", 0.23, 3], ["6166400", "FFS", 0.4, 44], ["6166432", "FFS", 0.46, 24], ["6166433", "FS", 1.0, 2], ["6166434", "FFS", 0.68, 26], ["6166435", "FS", 1.0, 1]], "6166336": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166337": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166338": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166339": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166340": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166341": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166342": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166343": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166344": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166345": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166346": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166347": [["6166295", "FFS", 0.01, 60], ["6166296", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 57], ["6166319", "FFS", 0.01, 57], ["6166323", "FFS", 0.01, 60], ["6166324", "FFS", 0.93, 1], ["6166325", "FFS", 0.82, 1], ["6166329", "FFS", 0.82, 1], ["6166332", "FFS", 0.01, 57], ["6166333", "FFS", 0.01, 57], ["6166334", "FFS", 0.67, 6], ["6166335", "FFS", 0.01, 57], ["6166348", "FFS", 0.5, 36], ["6166349", "FFS", 0.5, 36], ["6166350", "FFS", 0.5, 36], ["6166353", "FFS", 0.05, 43], ["6166354", "FFS", 0.5, 36], ["6166355", "FFS", 0.5, 36], ["6166357", "FFS", 0.5, 36], ["6166358", "FFS", 0.5, 36], ["6166383", "FFS", 0.5, 36], ["6166390", "FS", 1.0, 60], ["6166396", "FFS", 0.62, 6], ["6166400", "FS", 1.0, 60], ["6166403", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 9], ["6166424", "FFS", 0.2, 42], ["6166432", "FFS", 0.67, 34], ["6166433", "FS", 1.0, 7], ["6166434", "FFS", 0.82, 33]], "6166348": [["6166292", "FFS", 0.44, 2], ["6166295", "FS", 1.0, 9], ["6166296", "FFS", 0.01, 16], ["6166300", "FFS", 0.01, 9], ["6166316", "FS", 1.0, 11], ["6166319", "FS", 1.0, 11], ["6166323", "FFS", 0.01, 16], ["6166332", "FS", 1.0, 11], ["6166333", "FS", 1.0, 11], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 11], ["6166351", "FS", 1.0, 9], ["6166352", "FS", 1.0, 9], ["6166353", "FS", 1.0, 9], ["6166356", "FS", 1.0, 9], ["6166364", "SS", 0.25, 1], ["6166367", "SS", 0.25, 1], ["6166368", "FS", 1.0, 16], ["6166369", "FS", 1.0, 16], ["6166390", "FS", 1.0, 9], ["6166396", "FS", 1.0, 1], ["6166400", "FS", 1.0, 9], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166424", "FS", 1.0, 4], ["6166432", "FFS", 0.06, 2], ["6166434", "FS", 1.0, 3], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["16147472", "FFS", 0.11, 142], ["16147473", "FFS", 0.11, 142], ["16147477", "FFS", 0.44, 2], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166349": [["6166292", "FFS", 0.44, 2], ["6166295", "FS", 1.0, 9], ["6166296", "FFS", 0.01, 16], ["6166300", "FFS", 0.01, 9], ["6166316", "FS", 1.0, 11], ["6166319", "FS", 1.0, 11], ["6166323", "FFS", 0.01, 16], ["6166332", "FS", 1.0, 11], ["6166333", "FS", 1.0, 11], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 11], ["6166351", "FS", 1.0, 9], ["6166352", "FS", 1.0, 9], ["6166353", "FS", 1.0, 9], ["6166356", "FS", 1.0, 9], ["6166364", "SS", 0.25, 1], ["6166367", "SS", 0.25, 1], ["6166368", "FS", 1.0, 16], ["6166369", "FS", 1.0, 16], ["6166390", "FS", 1.0, 9], ["6166396", "FS", 1.0, 1], ["6166400", "FS", 1.0, 9], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166424", "FS", 1.0, 4], ["6166432", "FFS", 0.06, 2], ["6166434", "FS", 1.0, 3], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["16147472", "FFS", 0.11, 142], ["16147473", "FFS", 0.11, 142], ["16147477", "FFS", 0.44, 2], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166350": [["6166292", "FFS", 0.44, 2], ["6166295", "FS", 1.0, 9], ["6166296", "FFS", 0.01, 16], ["6166300", "FFS", 0.01, 9], ["6166316", "FS", 1.0, 11], ["6166319", "FS", 1.0, 11], ["6166323", "FFS", 0.01, 16], ["6166332", "FS", 1.0, 11], ["6166333", "FS", 1.0, 11], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 11], ["6166351", "FS", 1.0, 9], ["6166352", "FS", 1.0, 9], ["6166353", "FS", 1.0, 9], ["6166356", "FS", 1.0, 9], ["6166364", "SS", 0.25, 1], ["6166367", "SS", 0.25, 1], ["6166368", "FS", 1.0, 16], ["6166369", "FS", 1.0, 16], ["6166390", "FS", 1.0, 9], ["6166396", "FS", 1.0, 1], ["6166400", "FS", 1.0, 9], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166424", "FS", 1.0, 4], ["6166432", "FFS", 0.06, 2], ["6166434", "FS", 1.0, 3], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["16147472", "FFS", 0.11, 142], ["16147473", "FFS", 0.11, 142], ["16147477", "FFS", 0.44, 2], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166351": [["6166293", "FS", 1.0, 3], ["6166294", "FS", 1.0, 3], ["6166295", "FFS", 0.01, 5], ["6166297", "FFS", 0.01, 25], ["6166298", "FFS", 0.01, 25], ["6166299", "FFS", 0.01, 5], ["6166301", "FFS", 0.01, 25], ["6166303", "FFS", 0.01, 25], ["6166304", "FFS", 0.01, 1], ["6166305", "FFS", 0.01, 25], ["6166307", "FFS", 0.01, 1], ["6166309", "FFS", 0.01, 25], ["6166316", "FS", 1.0, 1], ["6166319", "FS", 1.0, 1], ["6166322", "FFS", 0.01, 25], ["6166332", "FS", 1.0, 1], ["6166333", "FS", 1.0, 1], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 1], ["6166336", "FFS", 0.01, 25], ["6166337", "FFS", 0.01, 25], ["6166338", "FFS", 0.01, 25], ["6166339", "FFS", 0.01, 25], ["6166340", "FFS", 0.01, 25], ["6166341", "FFS", 0.01, 25], ["6166342", "FFS", 0.01, 25], ["6166343", "FFS", 0.01, 25], ["6166344", "FFS", 0.01, 25], ["6166345", "FFS", 0.01, 25], ["6166346", "FFS", 0.01, 25], ["6166347", "FFS", 0.01, 25], ["6166360", "FS", 1.0, 1], ["6166362", "FS", 1.0, 1], ["6166390", "FS", 1.0, 5], ["6166398", "FS", 1.0, 1], ["6166399", "FS", 1.0, 1], ["6166400", "FS", 1.0, 5], ["6166402", "FS", 1.0, 1], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["16147472", "FFS", 0.94, 35], ["16147473", "FFS", 0.94, 35]], "6166352": [["6166293", "FS", 1.0, 3], ["6166294", "FS", 1.0, 3], ["6166295", "FFS", 0.01, 5], ["6166297", "FFS", 0.01, 25], ["6166298", "FFS", 0.01, 25], ["6166299", "FFS", 0.01, 5], ["6166301", "FFS", 0.01, 25], ["6166303", "FFS", 0.01, 25], ["6166304", "FFS", 0.01, 1], ["6166305", "FFS", 0.01, 25], ["6166307", "FFS", 0.01, 1], ["6166309", "FFS", 0.01, 25], ["6166316", "FS", 1.0, 1], ["6166319", "FS", 1.0, 1], ["6166322", "FFS", 0.01, 25], ["6166332", "FS", 1.0, 1], ["6166333", "FS", 1.0, 1], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 1], ["6166336", "FFS", 0.01, 25], ["6166337", "FFS", 0.01, 25], ["6166338", "FFS", 0.01, 25], ["6166339", "FFS", 0.01, 25], ["6166340", "FFS", 0.01, 25], ["6166341", "FFS", 0.01, 25], ["6166342", "FFS", 0.01, 25], ["6166343", "FFS", 0.01, 25], ["6166344", "FFS", 0.01, 25], ["6166345", "FFS", 0.01, 25], ["6166346", "FFS", 0.01, 25], ["6166347", "FFS", 0.01, 25], ["6166360", "FS", 1.0, 1], ["6166362", "FS", 1.0, 1], ["6166390", "FS", 1.0, 5], ["6166398", "FS", 1.0, 1], ["6166399", "FS", 1.0, 1], ["6166400", "FS", 1.0, 5], ["6166402", "FS", 1.0, 1], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["16147472", "FFS", 0.94, 35], ["16147473", "FFS", 0.94, 35]], "6166353": [["6166292", "FS", 1.0, 1], ["6166293", "FS", 1.0, 4], ["6166294", "FS", 1.0, 4], ["6166295", "FFS", 0.01, 32], ["6166300", "FS", 1.0, 6], ["6166316", "FFS", 0.01, 282], ["6166319", "FFS", 0.01, 282], ["6166332", "FFS", 0.01, 282], ["6166333", "FFS", 0.01, 282], ["6166334", "FS", 1.0, 5], ["6166335", "FFS", 0.01, 282], ["6166351", "FS", 1.0, 6], ["6166352", "FS", 1.0, 6], ["6166390", "FS", 1.0, 32], ["6166400", "FS", 1.0, 32], ["6166412", "FS", 1.0, 5], ["6166413", "FS", 1.0, 5], ["6166418", "FS", 1.0, 5], ["6166419", "FS", 1.0, 5], ["6166420", "FS", 1.0, 5], ["6166432", "FFS", 0.02, 444], ["6166433", "FFS", 0.3, 31], ["6166434", "FFS", 0.17, 381], ["6166435", "FFS", 0.52, 21], ["16147477", "FS", 1.0, 1]], "6166354": [["6166292", "FFS", 0.44, 2], ["6166295", "FS", 1.0, 9], ["6166296", "FFS", 0.01, 16], ["6166300", "FFS", 0.01, 9], ["6166316", "FS", 1.0, 11], ["6166319", "FS", 1.0, 11], ["6166323", "FFS", 0.01, 16], ["6166332", "FS", 1.0, 11], ["6166333", "FS", 1.0, 11], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 11], ["6166351", "FFS", 0.01, 9], ["6166352", "FFS", 0.01, 9], ["6166353", "FS", 1.0, 9], ["6166356", "FS", 1.0, 9], ["6166364", "SS", 0.25, 1], ["6166367", "SS", 0.25, 1], ["6166368", "FS", 1.0, 16], ["6166369", "FS", 1.0, 16], ["6166390", "FS", 1.0, 9], ["6166396", "FS", 1.0, 1], ["6166400", "FS", 1.0, 9], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166424", "FS", 1.0, 4], ["6166432", "FFS", 0.06, 2], ["6166434", "FS", 1.0, 3], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["16147472", "FFS", 0.11, 142], ["16147473", "FFS", 0.11, 142], ["16147477", "FFS", 0.44, 2], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166355": [["6166292", "FFS", 0.44, 2], ["6166295", "FS", 1.0, 9], ["6166296", "FFS", 0.01, 16], ["6166300", "FFS", 0.01, 9], ["6166316", "FS", 1.0, 11], ["6166319", "FS", 1.0, 11], ["6166323", "FFS", 0.01, 16], ["6166332", "FS", 1.0, 11], ["6166333", "FS", 1.0, 11], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 11], ["6166351", "FFS", 0.01, 9], ["6166352", "FFS", 0.01, 9], ["6166353", "FS", 1.0, 9], ["6166356", "FS", 1.0, 9], ["6166364", "SS", 0.25, 1], ["6166367", "SS", 0.25, 1], ["6166368", "FS", 1.0, 16], ["6166369", "FS", 1.0, 16], ["6166390", "FS", 1.0, 9], ["6166396", "FS", 1.0, 1], ["6166400", "FS", 1.0, 9], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166424", "FS", 1.0, 4], ["6166432", "FFS", 0.06, 2], ["6166434", "FS", 1.0, 3], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["16147472", "FFS", 0.11, 142], ["16147473", "FFS", 0.11, 142], ["16147477", "FFS", 0.44, 2], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166356": [["6166293", "FS", 1.0, 3], ["6166294", "FS", 1.0, 3], ["6166295", "FFS", 0.01, 5], ["6166297", "FFS", 0.01, 25], ["6166298", "FFS", 0.01, 25], ["6166299", "FFS", 0.01, 5], ["6166301", "FFS", 0.01, 25], ["6166303", "FFS", 0.01, 25], ["6166304", "FFS", 0.01, 1], ["6166305", "FFS", 0.01, 25], ["6166307", "FFS", 0.01, 1], ["6166309", "FFS", 0.01, 25], ["6166316", "FS", 1.0, 1], ["6166319", "FS", 1.0, 1], ["6166322", "FFS", 0.01, 25], ["6166332", "FS", 1.0, 1], ["6166333", "FS", 1.0, 1], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 1], ["6166336", "FFS", 0.01, 25], ["6166337", "FFS", 0.01, 25], ["6166338", "FFS", 0.01, 25], ["6166339", "FFS", 0.01, 25], ["6166340", "FFS", 0.01, 25], ["6166341", "FFS", 0.01, 25], ["6166342", "FFS", 0.01, 25], ["6166343", "FFS", 0.01, 25], ["6166344", "FFS", 0.01, 25], ["6166345", "FFS", 0.01, 25], ["6166346", "FFS", 0.01, 25], ["6166347", "FFS", 0.01, 25], ["6166353", "FS", 1.0, 6], ["6166360", "FS", 1.0, 1], ["6166362", "FS", 1.0, 1], ["6166390", "FS", 1.0, 5], ["6166398", "FS", 1.0, 1], ["6166399", "FS", 1.0, 1], ["6166400", "FS", 1.0, 5], ["6166402", "FS", 1.0, 1], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["16147472", "FFS", 0.94, 35], ["16147473", "FFS", 0.94, 35]], "6166357": [["6166292", "FFS", 0.44, 2], ["6166295", "FS", 1.0, 9], ["6166296", "FFS", 0.01, 16], ["6166300", "FFS", 0.01, 9], ["6166316", "FS", 1.0, 11], ["6166319", "FS", 1.0, 11], ["6166323", "FFS", 0.01, 16], ["6166332", "FS", 1.0, 11], ["6166333", "FS", 1.0, 11], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 11], ["6166351", "FFS", 0.01, 9], ["6166352", "FFS", 0.01, 9], ["6166353", "FS", 1.0, 9], ["6166356", "FFS", 0.01, 9], ["6166364", "SS", 0.25, 1], ["6166367", "SS", 0.25, 1], ["6166368", "FS", 1.0, 16], ["6166369", "FS", 1.0, 16], ["6166390", "FS", 1.0, 9], ["6166396", "FS", 1.0, 1], ["6166400", "FS", 1.0, 9], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166424", "FS", 1.0, 4], ["6166432", "FFS", 0.06, 2], ["6166434", "FS", 1.0, 3], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["16147472", "FFS", 0.11, 142], ["16147473", "FFS", 0.11, 142], ["16147477", "FFS", 0.44, 2], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166358": [["6166292", "FFS", 0.44, 2], ["6166295", "FS", 1.0, 9], ["6166296", "FFS", 0.01, 16], ["6166300", "FFS", 0.01, 9], ["6166316", "FS", 1.0, 11], ["6166319", "FS", 1.0, 11], ["6166323", "FFS", 0.01, 16], ["6166332", "FS", 1.0, 11], ["6166333", "FS", 1.0, 11], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 11], ["6166351", "FFS", 0.01, 9], ["6166352", "FFS", 0.01, 9], ["6166353", "FS", 1.0, 9], ["6166356", "FFS", 0.01, 9], ["6166364", "SS", 0.25, 1], ["6166367", "SS", 0.25, 1], ["6166368", "FS", 1.0, 16], ["6166369", "FS", 1.0, 16], ["6166390", "FS", 1.0, 9], ["6166396", "FS", 1.0, 1], ["6166400", "FS", 1.0, 9], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166424", "FS", 1.0, 4], ["6166432", "FFS", 0.06, 2], ["6166434", "FS", 1.0, 3], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["16147472", "FFS", 0.11, 142], ["16147473", "FFS", 0.11, 142], ["16147477", "FFS", 0.44, 2], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166359": [], "6166360": [["6166295", "FS", 1.0, 10], ["6166296", "FFS", 0.01, 20], ["6166297", "FFS", 0.01, 23], ["6166298", "FFS", 0.01, 23], ["6166301", "FFS", 0.01, 23], ["6166303", "FFS", 0.01, 23], ["6166305", "FFS", 0.01, 23], ["6166309", "FFS", 0.01, 23], ["6166316", "FFS", 0.01, 15], ["6166319", "FFS", 0.01, 15], ["6166322", "FFS", 0.01, 23], ["6166323", "FFS", 0.01, 20], ["6166332", "FFS", 0.01, 15], ["6166333", "FFS", 0.01, 15], ["6166334", "FS", 1.0, 4], ["6166335", "FFS", 0.01, 15], ["6166336", "FFS", 0.01, 23], ["6166337", "FFS", 0.01, 23], ["6166338", "FFS", 0.01, 23], ["6166339", "FFS", 0.01, 23], ["6166340", "FFS", 0.01, 23], ["6166341", "FFS", 0.01, 23], ["6166342", "FFS", 0.01, 23], ["6166343", "FFS", 0.01, 23], ["6166344", "FFS", 0.01, 23], ["6166345", "FFS", 0.01, 23], ["6166346", "FFS", 0.01, 23], ["6166347", "FFS", 0.01, 23], ["6166348", "FFS", 0.09, 6], ["6166349", "FFS", 0.09, 6], ["6166350", "FFS", 0.09, 6], ["6166353", "FFS", 0.1, 7], ["6166354", "FFS", 0.09, 6], ["6166355", "FFS", 0.09, 6], ["6166357", "FFS", 0.09, 6], ["6166358", "FFS", 0.09, 6], ["6166390", "FS", 1.0, 10], ["6166395", "FS", 1.0, 1], ["6166400", "FS", 1.0, 10], ["6166403", "FS", 1.0, 3], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 3], ["6166408", "FFS", 0.5, 5], ["6166410", "FS", 1.0, 2], ["6166411", "FS", 1.0, 2], ["6166412", "FS", 1.0, 4], ["6166413", "FS", 1.0, 4], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166418", "FS", 1.0, 4], ["6166419", "FS", 1.0, 4], ["6166420", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 5], ["6166424", "FS", 1.0, 1], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166362": [["6166295", "FS", 1.0, 10], ["6166296", "FFS", 0.01, 20], ["6166297", "FFS", 0.01, 23], ["6166298", "FFS", 0.01, 23], ["6166301", "FFS", 0.01, 23], ["6166303", "FFS", 0.01, 23], ["6166305", "FFS", 0.01, 23], ["6166309", "FFS", 0.01, 23], ["6166316", "FFS", 0.01, 15], ["6166319", "FFS", 0.01, 15], ["6166322", "FFS", 0.01, 23], ["6166323", "FFS", 0.01, 20], ["6166332", "FFS", 0.01, 15], ["6166333", "FFS", 0.01, 15], ["6166334", "FS", 1.0, 4], ["6166335", "FFS", 0.01, 15], ["6166336", "FFS", 0.01, 23], ["6166337", "FFS", 0.01, 23], ["6166338", "FFS", 0.01, 23], ["6166339", "FFS", 0.01, 23], ["6166340", "FFS", 0.01, 23], ["6166341", "FFS", 0.01, 23], ["6166342", "FFS", 0.01, 23], ["6166343", "FFS", 0.01, 23], ["6166344", "FFS", 0.01, 23], ["6166345", "FFS", 0.01, 23], ["6166346", "FFS", 0.01, 23], ["6166347", "FFS", 0.01, 23], ["6166348", "FFS", 0.09, 6], ["6166349", "FFS", 0.09, 6], ["6166350", "FFS", 0.09, 6], ["6166353", "FFS", 0.1, 7], ["6166354", "FFS", 0.09, 6], ["6166355", "FFS", 0.09, 6], ["6166357", "FFS", 0.09, 6], ["6166358", "FFS", 0.09, 6], ["6166390", "FS", 1.0, 10], ["6166395", "FS", 1.0, 1], ["6166400", "FS", 1.0, 10], ["6166403", "FS", 1.0, 3], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 3], ["6166408", "FFS", 0.5, 5], ["6166410", "FS", 1.0, 2], ["6166411", "FS", 1.0, 2], ["6166412", "FS", 1.0, 4], ["6166413", "FS", 1.0, 4], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166418", "FS", 1.0, 4], ["6166419", "FS", 1.0, 4], ["6166420", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 5], ["6166424", "FS", 1.0, 1], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166363": [], "6166364": [["6166296", "SS", 0.06, 8], ["6166297", "FS", 1.0, 4], ["6166298", "FS", 1.0, 4], ["6166301", "FS", 1.0, 4], ["6166303", "FS", 1.0, 4], ["6166305", "FS", 1.0, 4], ["6166309", "FS", 1.0, 4], ["6166316", "FFS", 0.74, 10], ["6166319", "FFS", 0.74, 10], ["6166322", "FS", 1.0, 4], ["6166323", "SS", 0.06, 8], ["6166332", "FFS", 0.74, 10], ["6166333", "FFS", 0.74, 10], ["6166335", "FFS", 0.74, 10], ["6166336", "FS", 1.0, 4], ["6166337", "FS", 1.0, 4], ["6166338", "FS", 1.0, 4], ["6166339", "FS", 1.0, 4], ["6166340", "FS", 1.0, 4], ["6166341", "FS", 1.0, 4], ["6166342", "FS", 1.0, 4], ["6166343", "FS", 1.0, 4], ["6166344", "FS", 1.0, 4], ["6166345", "FS", 1.0, 4], ["6166346", "FS", 1.0, 4], ["6166347", "FS", 1.0, 4], ["6166360", "SS", 0.04, 14], ["6166362", "SS", 0.04, 14], ["6166366", "FFS", 0.32, 1], ["6166398", "SS", 0.37, 14], ["6166399", "SS", 0.37, 14], ["6166402", "SS", 0.37, 14]], "6166366": [["6166296", "FFS", 0.01, 2], ["6166297", "SS", 0.36, 1], ["6166298", "SS", 0.36, 1], ["6166301", "SS", 0.36, 1], ["6166303", "SS", 0.36, 1], ["6166305", "SS", 0.36, 1], ["6166309", "SS", 0.36, 1], ["6166322", "SS", 0.36, 1], ["6166323", "FFS", 0.01, 2], ["6166336", "SS", 0.36, 1], ["6166337", "SS", 0.36, 1], ["6166338", "SS", 0.36, 1], ["6166339", "SS", 0.36, 1], ["6166340", "SS", 0.36, 1], ["6166341", "SS", 0.36, 1], ["6166342", "SS", 0.36, 1], ["6166343", "SS", 0.36, 1], ["6166344", "SS", 0.36, 1], ["6166345", "SS", 0.36, 1], ["6166346", "SS", 0.36, 1], ["6166347", "SS", 0.36, 1]], "6166367": [["6166296", "SS", 0.06, 8], ["6166297", "FS", 1.0, 4], ["6166298", "FS", 1.0, 4], ["6166301", "FS", 1.0, 4], ["6166303", "FS", 1.0, 4], ["6166305", "FS", 1.0, 4], ["6166309", "FS", 1.0, 4], ["6166316", "FFS", 0.74, 10], ["6166319", "FFS", 0.74, 10], ["6166322", "FS", 1.0, 4], ["6166323", "SS", 0.06, 8], ["6166332", "FFS", 0.74, 10], ["6166333", "FFS", 0.74, 10], ["6166335", "FFS", 0.74, 10], ["6166336", "FS", 1.0, 4], ["6166337", "FS", 1.0, 4], ["6166338", "FS", 1.0, 4], ["6166339", "FS", 1.0, 4], ["6166340", "FS", 1.0, 4], ["6166341", "FS", 1.0, 4], ["6166342", "FS", 1.0, 4], ["6166343", "FS", 1.0, 4], ["6166344", "FS", 1.0, 4], ["6166345", "FS", 1.0, 4], ["6166346", "FS", 1.0, 4], ["6166347", "FS", 1.0, 4], ["6166360", "SS", 0.04, 14], ["6166362", "SS", 0.04, 14], ["6166366", "FFS", 0.32, 1], ["6166398", "SS", 0.37, 14], ["6166399", "SS", 0.37, 14], ["6166402", "SS", 0.37, 14]], "6166368": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FS", 1.0, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166400", "FS", 1.0, 37], ["6166407", "FS", 1.0, 1], ["6166411", "FFS", 0.88, 12], ["6166424", "FFS", 0.11, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FS", 1.0, 5], ["6166434", "FS", 1.0, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "6166369": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FS", 1.0, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166400", "FS", 1.0, 37], ["6166407", "FS", 1.0, 1], ["6166411", "FFS", 0.88, 12], ["6166424", "FFS", 0.11, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FS", 1.0, 5], ["6166434", "FS", 1.0, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "6166370": [], "6166371": [], "6166372": [], "6166373": [], "6166374": [], "6166375": [], "6166376": [], "6166378": [["6166296", "FS", 1.0, 2], ["6166316", "FS", 1.0, 2], ["6166319", "FS", 1.0, 2], ["6166323", "FS", 1.0, 2], ["6166332", "FS", 1.0, 2], ["6166333", "FS", 1.0, 2], ["6166335", "FS", 1.0, 2], ["6166360", "FS", 1.0, 1], ["6166362", "FS", 1.0, 1], ["6166368", "FS", 1.0, 2], ["6166369", "FS", 1.0, 2], ["6166391", "FS", 1.0, 1], ["6166398", "FS", 1.0, 1], ["6166399", "FS", 1.0, 1], ["6166402", "FS", 1.0, 1], ["15643783", "FS", 1.0, 2], ["15643796", "FS", 1.0, 2], ["15659698", "FS", 1.0, 2], ["15659699", "FS", 1.0, 2], ["15659700", "FS", 1.0, 2], ["17502541", "FS", 1.0, 2], ["17502543", "FS", 1.0, 2], ["17502545", "FS", 1.0, 2]], "6166379": [["6166378", "FFS", 0.01, 2]], "6166383": [["6166292", "FFS", 0.44, 2], ["6166295", "FS", 1.0, 9], ["6166296", "FFS", 0.01, 16], ["6166300", "FFS", 0.01, 9], ["6166316", "FS", 1.0, 11], ["6166319", "FS", 1.0, 11], ["6166323", "FFS", 0.01, 16], ["6166332", "FS", 1.0, 11], ["6166333", "FS", 1.0, 11], ["6166334", "FS", 1.0, 1], ["6166335", "FS", 1.0, 11], ["6166351", "FFS", 0.01, 9], ["6166352", "FFS", 0.01, 9], ["6166353", "FS", 1.0, 9], ["6166356", "FFS", 0.01, 9], ["6166360", "FS", 1.0, 6], ["6166362", "FS", 1.0, 6], ["6166364", "SS", 0.25, 1], ["6166367", "SS", 0.25, 1], ["6166368", "FFS", 0.01, 16], ["6166369", "FFS", 0.01, 16], ["6166390", "FS", 1.0, 9], ["6166396", "FS", 1.0, 1], ["6166400", "FS", 1.0, 9], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166424", "FS", 1.0, 4], ["6166432", "FFS", 0.06, 2], ["6166434", "FS", 1.0, 3], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["16147472", "FFS", 0.11, 142], ["16147473", "FFS", 0.11, 142], ["16147477", "FFS", 0.44, 2], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166390": [["6166292", "SS", 0.66, 2], ["6166293", "FFS", 0.01, 8], ["6166294", "FFS", 0.01, 8], ["6166299", "FFS", 0.01, 3], ["6166302", "FFS", 0.01, 3], ["6166304", "FFS", 0.01, 1], ["6166308", "FS", 1.0, 1], ["6166397", "FFS", 0.62, 3], ["6166411", "FFS", 0.33, 2], ["6166422", "FFS", 0.09, 14], ["6166425", "FFS", 0.62, 3], ["6166426", "FFS", 0.62, 3], ["6166432", "FFS", 0.69, 34], ["6166434", "FS", 1.0, 32], ["6166435", "FS", 1.0, 5], ["16147477", "SS", 0.66, 2], ["16345501", "FFS", 0.33, 2], ["16345502", "FFS", 0.33, 2], ["16345503", "FFS", 0.33, 2], ["16345504", "FFS", 0.33, 2], ["16345505", "FFS", 0.33, 2], ["16345506", "FFS", 0.33, 2], ["17663819", "FFS", 0.33, 2], ["17663847", "FFS", 0.33, 2]], "6166391": [["6166296", "FS", 1.0, 1], ["6166297", "FFS", 0.01, 1], ["6166298", "FFS", 0.01, 1], ["6166301", "FFS", 0.01, 1], ["6166303", "FFS", 0.01, 1], ["6166305", "FFS", 0.01, 1], ["6166309", "FFS", 0.01, 1], ["6166322", "FFS", 0.01, 1], ["6166323", "FS", 1.0, 1], ["6166336", "FFS", 0.01, 1], ["6166337", "FFS", 0.01, 1], ["6166338", "FFS", 0.01, 1], ["6166339", "FFS", 0.01, 1], ["6166340", "FFS", 0.01, 1], ["6166341", "FFS", 0.01, 1], ["6166342", "FFS", 0.01, 1], ["6166343", "FFS", 0.01, 1], ["6166344", "FFS", 0.01, 1], ["6166345", "FFS", 0.01, 1], ["6166346", "FFS", 0.01, 1], ["6166347", "FFS", 0.01, 1], ["6166368", "FS", 1.0, 1], ["6166369", "FS", 1.0, 1], ["15643783", "FS", 1.0, 1], ["15643796", "FS", 1.0, 1], ["15659698", "FS", 1.0, 1], ["15659699", "FS", 1.0, 1], ["15659700", "FS", 1.0, 1], ["17502541", "FS", 1.0, 1], ["17502543", "FS", 1.0, 1], ["17502545", "FS", 1.0, 1]], "6166392": [], "6166393": [["6166295", "FS", 1.0, 2], ["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "SS", 0.45, 2], ["6166360", "FS", 1.0, 2], ["6166362", "FS", 1.0, 2], ["6166390", "FS", 1.0, 2], ["6166395", "FS", 1.0, 1], ["6166400", "FS", 1.0, 2], ["6166422", "FS", 1.0, 1]], "6166394": [["6166295", "FS", 1.0, 2], ["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "SS", 0.45, 2], ["6166360", "FS", 1.0, 2], ["6166362", "FS", 1.0, 2], ["6166390", "FS", 1.0, 2], ["6166395", "FS", 1.0, 1], ["6166400", "FS", 1.0, 2], ["6166422", "FS", 1.0, 1]], "6166395": [["6166404", "FS", 1.0, 1], ["6166408", "SS", 0.3, 1]], "6166396": [["6166295", "FFS", 0.01, 7], ["6166316", "FFS", 0.48, 5], ["6166319", "FFS", 0.48, 5], ["6166332", "FFS", 0.48, 5], ["6166333", "FFS", 0.48, 5], ["6166334", "FFS", 0.01, 3], ["6166335", "FFS", 0.48, 5], ["6166353", "FFS", 0.01, 54], ["6166360", "FS", 1.0, 5], ["6166362", "FS", 1.0, 5], ["6166390", "FFS", 0.01, 7], ["6166393", "FS", 1.0, 2], ["6166394", "FS", 1.0, 2], ["6166395", "FS", 1.0, 1], ["6166398", "FS", 1.0, 5], ["6166399", "FS", 1.0, 5], ["6166400", "FS", 1.0, 7], ["6166402", "FS", 1.0, 5], ["6166408", "SS", 0.5, 1], ["6166410", "FS", 1.0, 2], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166432", "FFS", 0.12, 41], ["6166433", "FFS", 0.36, 9], ["6166434", "FS", 1.0, 35], ["6166435", "FS", 1.0, 5]], "6166397": [["6166297", "FFS", 0.1, 1], ["6166298", "FFS", 0.1, 1], ["6166301", "FFS", 0.1, 1], ["6166303", "FFS", 0.1, 1], ["6166305", "FFS", 0.1, 1], ["6166309", "FFS", 0.1, 1], ["6166322", "FFS", 0.1, 1], ["6166336", "FFS", 0.1, 1], ["6166337", "FFS", 0.1, 1], ["6166338", "FFS", 0.1, 1], ["6166339", "FFS", 0.1, 1], ["6166340", "FFS", 0.1, 1], ["6166341", "FFS", 0.1, 1], ["6166342", "FFS", 0.1, 1], ["6166343", "FFS", 0.1, 1], ["6166344", "FFS", 0.1, 1], ["6166345", "FFS", 0.1, 1], ["6166346", "FFS", 0.1, 1], ["6166347", "FFS", 0.1, 1], ["6166353", "SS", 0.14, 1], ["6166360", "SS", 0.17, 2], ["6166362", "SS", 0.17, 2], ["6166393", "FS", 1.0, 2], ["6166394", "FS", 1.0, 2], ["6166403", "FS", 1.0, 1], ["6166405", "FS", 1.0, 1], ["6166422", "FS", 1.0, 2]], "6166398": [["6166295", "FS", 1.0, 10], ["6166296", "FFS", 0.01, 20], ["6166297", "FFS", 0.01, 23], ["6166298", "FFS", 0.01, 23], ["6166301", "FFS", 0.01, 23], ["6166303", "FFS", 0.01, 23], ["6166305", "FFS", 0.01, 23], ["6166309", "FFS", 0.01, 23], ["6166316", "FFS", 0.01, 15], ["6166319", "FFS", 0.01, 15], ["6166322", "FFS", 0.01, 23], ["6166323", "FFS", 0.01, 20], ["6166332", "FFS", 0.01, 15], ["6166333", "FFS", 0.01, 15], ["6166334", "FS", 1.0, 4], ["6166335", "FFS", 0.01, 15], ["6166336", "FFS", 0.01, 23], ["6166337", "FFS", 0.01, 23], ["6166338", "FFS", 0.01, 23], ["6166339", "FFS", 0.01, 23], ["6166340", "FFS", 0.01, 23], ["6166341", "FFS", 0.01, 23], ["6166342", "FFS", 0.01, 23], ["6166343", "FFS", 0.01, 23], ["6166344", "FFS", 0.01, 23], ["6166345", "FFS", 0.01, 23], ["6166346", "FFS", 0.01, 23], ["6166347", "FFS", 0.01, 23], ["6166348", "FFS", 0.09, 6], ["6166349", "FFS", 0.09, 6], ["6166350", "FFS", 0.09, 6], ["6166353", "FFS", 0.1, 7], ["6166354", "FFS", 0.09, 6], ["6166355", "FFS", 0.09, 6], ["6166357", "FFS", 0.09, 6], ["6166358", "FFS", 0.09, 6], ["6166368", "FFS", 0.01, 20], ["6166369", "FFS", 0.01, 20], ["6166383", "FFS", 0.09, 6], ["6166390", "FS", 1.0, 10], ["6166393", "FS", 1.0, 2], ["6166394", "FS", 1.0, 2], ["6166395", "FS", 1.0, 1], ["6166397", "FS", 1.0, 2], ["6166400", "FS", 1.0, 10], ["6166403", "FS", 1.0, 3], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 3], ["6166408", "FFS", 0.5, 5], ["6166410", "FS", 1.0, 2], ["6166411", "FS", 1.0, 2], ["6166412", "FS", 1.0, 4], ["6166413", "FS", 1.0, 4], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166418", "FS", 1.0, 4], ["6166419", "FS", 1.0, 4], ["6166420", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 5], ["6166424", "FS", 1.0, 1], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166399": [["6166295", "FS", 1.0, 10], ["6166296", "FFS", 0.01, 20], ["6166297", "FFS", 0.01, 23], ["6166298", "FFS", 0.01, 23], ["6166301", "FFS", 0.01, 23], ["6166303", "FFS", 0.01, 23], ["6166305", "FFS", 0.01, 23], ["6166309", "FFS", 0.01, 23], ["6166316", "FFS", 0.01, 15], ["6166319", "FFS", 0.01, 15], ["6166322", "FFS", 0.01, 23], ["6166323", "FFS", 0.01, 20], ["6166332", "FFS", 0.01, 15], ["6166333", "FFS", 0.01, 15], ["6166334", "FS", 1.0, 4], ["6166335", "FFS", 0.01, 15], ["6166336", "FFS", 0.01, 23], ["6166337", "FFS", 0.01, 23], ["6166338", "FFS", 0.01, 23], ["6166339", "FFS", 0.01, 23], ["6166340", "FFS", 0.01, 23], ["6166341", "FFS", 0.01, 23], ["6166342", "FFS", 0.01, 23], ["6166343", "FFS", 0.01, 23], ["6166344", "FFS", 0.01, 23], ["6166345", "FFS", 0.01, 23], ["6166346", "FFS", 0.01, 23], ["6166347", "FFS", 0.01, 23], ["6166348", "FFS", 0.09, 6], ["6166349", "FFS", 0.09, 6], ["6166350", "FFS", 0.09, 6], ["6166353", "FFS", 0.1, 7], ["6166354", "FFS", 0.09, 6], ["6166355", "FFS", 0.09, 6], ["6166357", "FFS", 0.09, 6], ["6166358", "FFS", 0.09, 6], ["6166368", "FFS", 0.01, 20], ["6166369", "FFS", 0.01, 20], ["6166383", "FFS", 0.09, 6], ["6166390", "FS", 1.0, 10], ["6166393", "FS", 1.0, 2], ["6166394", "FS", 1.0, 2], ["6166395", "FS", 1.0, 1], ["6166397", "FS", 1.0, 2], ["6166400", "FS", 1.0, 10], ["6166403", "FS", 1.0, 3], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 3], ["6166408", "FFS", 0.5, 5], ["6166410", "FS", 1.0, 2], ["6166411", "FS", 1.0, 2], ["6166412", "FS", 1.0, 4], ["6166413", "FS", 1.0, 4], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166418", "FS", 1.0, 4], ["6166419", "FS", 1.0, 4], ["6166420", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 5], ["6166424", "FS", 1.0, 1], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166400": [["6166292", "SS", 0.66, 2], ["6166293", "FFS", 0.01, 8], ["6166294", "FFS", 0.01, 8], ["6166299", "FFS", 0.01, 3], ["6166302", "FFS", 0.01, 3], ["6166304", "FFS", 0.01, 1], ["6166308", "FS", 1.0, 1], ["6166397", "FFS", 0.62, 3], ["6166411", "FFS", 0.33, 2], ["6166422", "FFS", 0.09, 14], ["6166425", "FFS", 0.62, 3], ["6166426", "FFS", 0.62, 3], ["6166432", "FFS", 0.69, 34], ["6166434", "FS", 1.0, 32], ["6166435", "FS", 1.0, 5], ["16147477", "SS", 0.66, 2], ["16345501", "FFS", 0.33, 2], ["16345502", "FFS", 0.33, 2], ["16345503", "FFS", 0.33, 2], ["16345504", "FFS", 0.33, 2], ["16345505", "FFS", 0.33, 2], ["16345506", "FFS", 0.33, 2], ["17663819", "FFS", 0.33, 2], ["17663847", "FFS", 0.33, 2]], "6166401": [["6166334", "FS", 1.0, 1], ["6166360", "SS", 0.1, 2], ["6166362", "SS", 0.1, 2], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FFS", 0.2, 1], ["6166398", "SS", 0.1, 2], ["6166399", "SS", 0.1, 2], ["6166402", "SS", 0.1, 2], ["6166403", "FS", 1.0, 1], ["6166405", "FS", 1.0, 1], ["6166407", "FS", 1.0, 1], ["6166408", "FS", 1.0, 1], ["6166410", "FS", 1.0, 1], ["6166412", "FS", 1.0, 1], ["6166413", "FS", 1.0, 1], ["6166415", "FS", 1.0, 1], ["6166417", "FS", 1.0, 1], ["6166418", "FS", 1.0, 1], ["6166419", "FS", 1.0, 1], ["6166420", "FS", 1.0, 1], ["6166422", "FS", 1.0, 1], ["6166431", "FS", 1.0, 1], ["17502319", "FS", 1.0, 1], ["17502544", "FS", 1.0, 1]], "6166402": [["6166295", "FS", 1.0, 10], ["6166296", "FFS", 0.01, 20], ["6166297", "FFS", 0.01, 23], ["6166298", "FFS", 0.01, 23], ["6166301", "FFS", 0.01, 23], ["6166303", "FFS", 0.01, 23], ["6166305", "FFS", 0.01, 23], ["6166309", "FFS", 0.01, 23], ["6166316", "FFS", 0.01, 15], ["6166319", "FFS", 0.01, 15], ["6166322", "FFS", 0.01, 23], ["6166323", "FFS", 0.01, 20], ["6166332", "FFS", 0.01, 15], ["6166333", "FFS", 0.01, 15], ["6166334", "FS", 1.0, 4], ["6166335", "FFS", 0.01, 15], ["6166336", "FFS", 0.01, 23], ["6166337", "FFS", 0.01, 23], ["6166338", "FFS", 0.01, 23], ["6166339", "FFS", 0.01, 23], ["6166340", "FFS", 0.01, 23], ["6166341", "FFS", 0.01, 23], ["6166342", "FFS", 0.01, 23], ["6166343", "FFS", 0.01, 23], ["6166344", "FFS", 0.01, 23], ["6166345", "FFS", 0.01, 23], ["6166346", "FFS", 0.01, 23], ["6166347", "FFS", 0.01, 23], ["6166348", "FFS", 0.09, 6], ["6166349", "FFS", 0.09, 6], ["6166350", "FFS", 0.09, 6], ["6166353", "FFS", 0.1, 7], ["6166354", "FFS", 0.09, 6], ["6166355", "FFS", 0.09, 6], ["6166357", "FFS", 0.09, 6], ["6166358", "FFS", 0.09, 6], ["6166368", "FFS", 0.01, 20], ["6166369", "FFS", 0.01, 20], ["6166383", "FFS", 0.09, 6], ["6166390", "FS", 1.0, 10], ["6166393", "FS", 1.0, 2], ["6166394", "FS", 1.0, 2], ["6166395", "FS", 1.0, 1], ["6166397", "FS", 1.0, 2], ["6166400", "FS", 1.0, 10], ["6166403", "FS", 1.0, 3], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 3], ["6166408", "FFS", 0.5, 5], ["6166410", "FS", 1.0, 2], ["6166411", "FS", 1.0, 2], ["6166412", "FS", 1.0, 4], ["6166413", "FS", 1.0, 4], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166418", "FS", 1.0, 4], ["6166419", "FS", 1.0, 4], ["6166420", "FS", 1.0, 4], ["6166422", "FFS", 0.82, 5], ["6166424", "FS", 1.0, 1], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166403": [["6166295", "FFS", 0.57, 4], ["6166296", "FS", 1.0, 6], ["6166316", "FS", 1.0, 2], ["6166319", "FS", 1.0, 2], ["6166323", "FS", 1.0, 6], ["6166332", "FS", 1.0, 2], ["6166333", "FS", 1.0, 2], ["6166335", "FS", 1.0, 2], ["6166353", "FFS", 0.01, 45], ["6166368", "FS", 1.0, 6], ["6166369", "FS", 1.0, 6], ["6166390", "FFS", 0.57, 4], ["6166393", "FFS", 0.48, 3], ["6166394", "FFS", 0.48, 3], ["6166396", "FFS", 0.02, 19], ["6166400", "FFS", 0.57, 4], ["6166432", "FS", 1.0, 14], ["6166434", "FS", 1.0, 13], ["9350109", "FFS", 0.65, 2]], "6166404": [["6166295", "FS", 1.0, 7], ["6166296", "FS", 1.0, 10], ["6166297", "FS", 1.0, 6], ["6166298", "FS", 1.0, 6], ["6166301", "FS", 1.0, 6], ["6166303", "FS", 1.0, 6], ["6166305", "FS", 1.0, 6], ["6166309", "FS", 1.0, 6], ["6166316", "FS", 1.0, 2], ["6166319", "FS", 1.0, 2], ["6166322", "FS", 1.0, 6], ["6166323", "FS", 1.0, 10], ["6166332", "FS", 1.0, 2], ["6166333", "FS", 1.0, 2], ["6166335", "FS", 1.0, 2], ["6166336", "FS", 1.0, 6], ["6166337", "FS", 1.0, 6], ["6166338", "FS", 1.0, 6], ["6166339", "FS", 1.0, 6], ["6166340", "FS", 1.0, 6], ["6166341", "FS", 1.0, 6], ["6166342", "FS", 1.0, 6], ["6166343", "FS", 1.0, 6], ["6166344", "FS", 1.0, 6], ["6166345", "FS", 1.0, 6], ["6166346", "FS", 1.0, 6], ["6166347", "FS", 1.0, 6], ["6166353", "FFS", 0.01, 10], ["6166368", "FS", 1.0, 10], ["6166369", "FS", 1.0, 10], ["6166390", "FS", 1.0, 7], ["6166393", "FS", 1.0, 5], ["6166394", "FS", 1.0, 5], ["6166396", "FFS", 0.18, 9], ["6166397", "SS", 0.8, 4], ["6166400", "FS", 1.0, 7], ["6166401", "SS", 0.67, 1], ["6166403", "FFS", 0.01, 10], ["6166405", "FFS", 0.15, 10], ["6166407", "FS", 1.0, 5], ["6166408", "SS", 0.2, 6], ["6166422", "FS", 1.0, 5], ["6166424", "FFS", 0.21, 8], ["6166431", "FFS", 0.56, 6], ["6166434", "FS", 1.0, 1], ["15643783", "FS", 1.0, 10], ["15643796", "FS", 1.0, 10], ["15659698", "FS", 1.0, 10], ["15659699", "FS", 1.0, 10], ["15659700", "FS", 1.0, 10], ["17502319", "FFS", 0.56, 6], ["17502541", "FS", 1.0, 10], ["17502543", "FS", 1.0, 10], ["17502544", "FFS", 0.56, 6], ["17502545", "FS", 1.0, 10]], "6166405": [["6166295", "FFS", 0.57, 4], ["6166296", "FS", 1.0, 6], ["6166316", "FS", 1.0, 2], ["6166319", "FS", 1.0, 2], ["6166323", "FS", 1.0, 6], ["6166332", "FS", 1.0, 2], ["6166333", "FS", 1.0, 2], ["6166335", "FS", 1.0, 2], ["6166353", "FFS", 0.01, 45], ["6166368", "FS", 1.0, 6], ["6166369", "FS", 1.0, 6], ["6166390", "FFS", 0.57, 4], ["6166393", "FFS", 0.48, 3], ["6166394", "FFS", 0.48, 3], ["6166396", "FFS", 0.02, 19], ["6166400", "FFS", 0.57, 4], ["6166432", "FS", 1.0, 14], ["6166434", "FS", 1.0, 13], ["9350109", "FFS", 0.65, 2]], "6166407": [["6166295", "FS", 1.0, 2], ["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "SS", 0.45, 2], ["6166360", "FS", 1.0, 2], ["6166362", "FS", 1.0, 2], ["6166390", "FS", 1.0, 2], ["6166395", "FS", 1.0, 1], ["6166396", "FS", 1.0, 2], ["6166397", "FS", 1.0, 2], ["6166398", "FS", 1.0, 2], ["6166399", "FS", 1.0, 2], ["6166400", "FS", 1.0, 2], ["6166402", "FS", 1.0, 2], ["6166403", "FFS", 0.5, 3], ["6166405", "FFS", 0.5, 3], ["6166422", "FS", 1.0, 1]], "6166408": [["6166295", "FS", 1.0, 4], ["6166296", "FFS", 0.01, 18], ["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166323", "FFS", 0.01, 18], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166368", "FFS", 0.01, 18], ["6166369", "FFS", 0.01, 18], ["6166390", "FS", 1.0, 4], ["6166393", "FFS", 0.43, 4], ["6166394", "FFS", 0.43, 4], ["6166397", "FS", 1.0, 2], ["6166400", "FS", 1.0, 4], ["6166403", "FFS", 0.11, 5], ["6166405", "FFS", 0.11, 5], ["6166407", "FFS", 0.43, 4], ["6166422", "FFS", 0.35, 8], ["6166432", "FS", 1.0, 2], ["6166434", "FS", 1.0, 2], ["9350109", "FFS", 0.7, 2]], "6166409": [["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166403", "FFS", 0.79, 1], ["6166404", "FFS", 0.01, 2], ["6166405", "FFS", 0.79, 1], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.6, 1], ["6166424", "FFS", 0.73, 1], ["6166431", "FFS", 0.1, 1], ["9350109", "FS", 1.0, 1], ["17502319", "FFS", 0.1, 1], ["17502544", "FFS", 0.1, 1]], "6166410": [["6166334", "FFS", 0.01, 2], ["6166409", "FS", 1.0, 1], ["6166411", "FS", 1.0, 1], ["6166412", "FS", 1.0, 2], ["6166413", "FS", 1.0, 2], ["6166415", "SS", 0.86, 2], ["6166417", "SS", 0.86, 2], ["6166418", "FS", 1.0, 2], ["6166419", "FS", 1.0, 2], ["6166420", "FS", 1.0, 2], ["16345501", "FS", 1.0, 1], ["16345502", "FS", 1.0, 1], ["16345503", "FS", 1.0, 1], ["16345504", "FS", 1.0, 1], ["16345505", "FS", 1.0, 1], ["16345506", "FS", 1.0, 1], ["17663819", "FS", 1.0, 1], ["17663847", "FS", 1.0, 1]], "6166411": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.5, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17502319", "FFS", 0.5, 17], ["17502544", "FFS", 0.5, 17]], "6166412": [["6166295", "SS", 0.89, 3], ["6166296", "FS", 1.0, 2], ["6166297", "SS", 0.52, 6], ["6166298", "SS", 0.52, 6], ["6166301", "SS", 0.52, 6], ["6166303", "SS", 0.52, 6], ["6166305", "SS", 0.52, 6], ["6166309", "SS", 0.52, 6], ["6166316", "FFS", 0.56, 5], ["6166319", "FFS", 0.56, 5], ["6166322", "SS", 0.52, 6], ["6166323", "FS", 1.0, 2], ["6166332", "FFS", 0.56, 5], ["6166333", "FFS", 0.56, 5], ["6166335", "FFS", 0.56, 5], ["6166336", "SS", 0.52, 6], ["6166337", "SS", 0.52, 6], ["6166338", "SS", 0.52, 6], ["6166339", "SS", 0.52, 6], ["6166340", "SS", 0.52, 6], ["6166341", "SS", 0.52, 6], ["6166342", "SS", 0.52, 6], ["6166343", "SS", 0.52, 6], ["6166344", "SS", 0.52, 6], ["6166345", "SS", 0.52, 6], ["6166346", "SS", 0.52, 6], ["6166347", "SS", 0.52, 6], ["6166368", "FS", 1.0, 2], ["6166369", "FS", 1.0, 2], ["6166390", "SS", 0.89, 3], ["6166396", "FFS", 0.01, 3], ["6166397", "FS", 1.0, 1], ["6166400", "SS", 0.89, 3], ["6166404", "FS", 1.0, 1], ["6166408", "FFS", 0.73, 2], ["6166411", "FS", 1.0, 2], ["6166424", "FS", 1.0, 2], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166434", "FS", 1.0, 4], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166413": [["6166295", "SS", 0.89, 3], ["6166296", "FS", 1.0, 2], ["6166297", "SS", 0.52, 6], ["6166298", "SS", 0.52, 6], ["6166301", "SS", 0.52, 6], ["6166303", "SS", 0.52, 6], ["6166305", "SS", 0.52, 6], ["6166309", "SS", 0.52, 6], ["6166316", "FFS", 0.56, 5], ["6166319", "FFS", 0.56, 5], ["6166322", "SS", 0.52, 6], ["6166323", "FS", 1.0, 2], ["6166332", "FFS", 0.56, 5], ["6166333", "FFS", 0.56, 5], ["6166335", "FFS", 0.56, 5], ["6166336", "SS", 0.52, 6], ["6166337", "SS", 0.52, 6], ["6166338", "SS", 0.52, 6], ["6166339", "SS", 0.52, 6], ["6166340", "SS", 0.52, 6], ["6166341", "SS", 0.52, 6], ["6166342", "SS", 0.52, 6], ["6166343", "SS", 0.52, 6], ["6166344", "SS", 0.52, 6], ["6166345", "SS", 0.52, 6], ["6166346", "SS", 0.52, 6], ["6166347", "SS", 0.52, 6], ["6166368", "FS", 1.0, 2], ["6166369", "FS", 1.0, 2], ["6166390", "SS", 0.89, 3], ["6166396", "FFS", 0.01, 3], ["6166397", "FS", 1.0, 1], ["6166400", "SS", 0.89, 3], ["6166404", "FS", 1.0, 1], ["6166408", "FFS", 0.73, 2], ["6166411", "FS", 1.0, 2], ["6166424", "FS", 1.0, 2], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166434", "FS", 1.0, 4], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166415": [["6166316", "FS", 1.0, 1], ["6166319", "FS", 1.0, 1], ["6166332", "FS", 1.0, 1], ["6166333", "FS", 1.0, 1], ["6166334", "FS", 1.0, 7], ["6166335", "FS", 1.0, 1], ["6166353", "FS", 1.0, 1], ["6166404", "FS", 1.0, 1], ["6166412", "FS", 1.0, 7], ["6166413", "FS", 1.0, 7], ["6166418", "FS", 1.0, 7], ["6166419", "FS", 1.0, 7], ["6166420", "FS", 1.0, 7], ["6166422", "FS", 1.0, 3]], "6166417": [["6166316", "FS", 1.0, 1], ["6166319", "FS", 1.0, 1], ["6166332", "FS", 1.0, 1], ["6166333", "FS", 1.0, 1], ["6166334", "FS", 1.0, 7], ["6166335", "FS", 1.0, 1], ["6166353", "FS", 1.0, 1], ["6166404", "FS", 1.0, 1], ["6166412", "FS", 1.0, 7], ["6166413", "FS", 1.0, 7], ["6166418", "FS", 1.0, 7], ["6166419", "FS", 1.0, 7], ["6166420", "FS", 1.0, 7], ["6166422", "FS", 1.0, 3]], "6166418": [["6166295", "SS", 0.89, 3], ["6166296", "FS", 1.0, 2], ["6166297", "SS", 0.52, 6], ["6166298", "SS", 0.52, 6], ["6166301", "SS", 0.52, 6], ["6166303", "SS", 0.52, 6], ["6166305", "SS", 0.52, 6], ["6166309", "SS", 0.52, 6], ["6166316", "FFS", 0.56, 5], ["6166319", "FFS", 0.56, 5], ["6166322", "SS", 0.52, 6], ["6166323", "FS", 1.0, 2], ["6166332", "FFS", 0.56, 5], ["6166333", "FFS", 0.56, 5], ["6166335", "FFS", 0.56, 5], ["6166336", "SS", 0.52, 6], ["6166337", "SS", 0.52, 6], ["6166338", "SS", 0.52, 6], ["6166339", "SS", 0.52, 6], ["6166340", "SS", 0.52, 6], ["6166341", "SS", 0.52, 6], ["6166342", "SS", 0.52, 6], ["6166343", "SS", 0.52, 6], ["6166344", "SS", 0.52, 6], ["6166345", "SS", 0.52, 6], ["6166346", "SS", 0.52, 6], ["6166347", "SS", 0.52, 6], ["6166368", "FS", 1.0, 2], ["6166369", "FS", 1.0, 2], ["6166390", "SS", 0.89, 3], ["6166396", "FFS", 0.01, 3], ["6166397", "FS", 1.0, 1], ["6166400", "SS", 0.89, 3], ["6166404", "FS", 1.0, 1], ["6166408", "FFS", 0.73, 2], ["6166411", "FS", 1.0, 2], ["6166424", "FS", 1.0, 2], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166434", "FS", 1.0, 4], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166419": [["6166295", "SS", 0.89, 3], ["6166296", "FS", 1.0, 2], ["6166297", "SS", 0.52, 6], ["6166298", "SS", 0.52, 6], ["6166301", "SS", 0.52, 6], ["6166303", "SS", 0.52, 6], ["6166305", "SS", 0.52, 6], ["6166309", "SS", 0.52, 6], ["6166316", "FFS", 0.56, 5], ["6166319", "FFS", 0.56, 5], ["6166322", "SS", 0.52, 6], ["6166323", "FS", 1.0, 2], ["6166332", "FFS", 0.56, 5], ["6166333", "FFS", 0.56, 5], ["6166335", "FFS", 0.56, 5], ["6166336", "SS", 0.52, 6], ["6166337", "SS", 0.52, 6], ["6166338", "SS", 0.52, 6], ["6166339", "SS", 0.52, 6], ["6166340", "SS", 0.52, 6], ["6166341", "SS", 0.52, 6], ["6166342", "SS", 0.52, 6], ["6166343", "SS", 0.52, 6], ["6166344", "SS", 0.52, 6], ["6166345", "SS", 0.52, 6], ["6166346", "SS", 0.52, 6], ["6166347", "SS", 0.52, 6], ["6166368", "FS", 1.0, 2], ["6166369", "FS", 1.0, 2], ["6166390", "SS", 0.89, 3], ["6166396", "FFS", 0.01, 3], ["6166397", "FS", 1.0, 1], ["6166400", "SS", 0.89, 3], ["6166404", "FS", 1.0, 1], ["6166408", "FFS", 0.73, 2], ["6166411", "FS", 1.0, 2], ["6166424", "FS", 1.0, 2], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166434", "FS", 1.0, 4], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166420": [["6166295", "SS", 0.89, 3], ["6166296", "FS", 1.0, 2], ["6166297", "SS", 0.52, 6], ["6166298", "SS", 0.52, 6], ["6166301", "SS", 0.52, 6], ["6166303", "SS", 0.52, 6], ["6166305", "SS", 0.52, 6], ["6166309", "SS", 0.52, 6], ["6166316", "FFS", 0.56, 5], ["6166319", "FFS", 0.56, 5], ["6166322", "SS", 0.52, 6], ["6166323", "FS", 1.0, 2], ["6166332", "FFS", 0.56, 5], ["6166333", "FFS", 0.56, 5], ["6166335", "FFS", 0.56, 5], ["6166336", "SS", 0.52, 6], ["6166337", "SS", 0.52, 6], ["6166338", "SS", 0.52, 6], ["6166339", "SS", 0.52, 6], ["6166340", "SS", 0.52, 6], ["6166341", "SS", 0.52, 6], ["6166342", "SS", 0.52, 6], ["6166343", "SS", 0.52, 6], ["6166344", "SS", 0.52, 6], ["6166345", "SS", 0.52, 6], ["6166346", "SS", 0.52, 6], ["6166347", "SS", 0.52, 6], ["6166368", "FS", 1.0, 2], ["6166369", "FS", 1.0, 2], ["6166390", "SS", 0.89, 3], ["6166396", "FFS", 0.01, 3], ["6166397", "FS", 1.0, 1], ["6166400", "SS", 0.89, 3], ["6166404", "FS", 1.0, 1], ["6166408", "FFS", 0.73, 2], ["6166411", "FS", 1.0, 2], ["6166424", "FS", 1.0, 2], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166434", "FS", 1.0, 4], ["16345501", "FS", 1.0, 2], ["16345502", "FS", 1.0, 2], ["16345503", "FS", 1.0, 2], ["16345504", "FS", 1.0, 2], ["16345505", "FS", 1.0, 2], ["16345506", "FS", 1.0, 2], ["17663819", "FS", 1.0, 2], ["17663847", "FS", 1.0, 2]], "6166422": [["6166296", "FFS", 0.01, 10], ["6166300", "FS", 1.0, 1], ["6166316", "FS", 1.0, 2], ["6166319", "FS", 1.0, 2], ["6166323", "FFS", 0.01, 10], ["6166332", "FS", 1.0, 2], ["6166333", "FS", 1.0, 2], ["6166334", "FFS", 0.01, 5], ["6166335", "FS", 1.0, 2], ["6166351", "FS", 1.0, 1], ["6166352", "FS", 1.0, 1], ["6166353", "FFS", 0.2, 12], ["6166356", "FS", 1.0, 1], ["6166368", "FFS", 0.01, 10], ["6166369", "FFS", 0.01, 10], ["6166396", "FFS", 0.58, 8], ["6166403", "FFS", 0.17, 6], ["6166405", "FFS", 0.17, 6], ["6166410", "FS", 1.0, 4], ["6166411", "SS", 0.04, 9], ["6166412", "FFS", 0.01, 5], ["6166413", "FFS", 0.01, 5], ["6166418", "FFS", 0.01, 5], ["6166419", "FFS", 0.01, 5], ["6166420", "FFS", 0.01, 5], ["6166434", "FS", 1.0, 1], ["16345501", "SS", 0.04, 9], ["16345502", "SS", 0.04, 9], ["16345503", "SS", 0.04, 9], ["16345504", "SS", 0.04, 9], ["16345505", "SS", 0.04, 9], ["16345506", "SS", 0.04, 9], ["17663819", "SS", 0.04, 9], ["17663847", "SS", 0.04, 9]], "6166423": [], "6166424": [["6166295", "FFS", 0.01, 24], ["6166300", "FS", 1.0, 2], ["6166316", "FFS", 0.25, 23], ["6166319", "FFS", 0.25, 23], ["6166332", "FFS", 0.25, 23], ["6166333", "FFS", 0.25, 23], ["6166335", "FFS", 0.25, 23], ["6166351", "FS", 1.0, 2], ["6166352", "FS", 1.0, 2], ["6166353", "FFS", 0.09, 126], ["6166356", "FS", 1.0, 2], ["6166390", "FFS", 0.01, 24], ["6166393", "FFS", 0.62, 3], ["6166394", "FFS", 0.62, 3], ["6166396", "FFS", 0.01, 27], ["6166400", "FFS", 0.01, 24], ["6166403", "FFS", 0.21, 11], ["6166405", "FFS", 0.21, 11], ["6166407", "FFS", 0.62, 3], ["6166408", "FFS", 0.01, 6], ["6166411", "FS", 1.0, 6], ["6166422", "SS", 0.29, 2], ["6166423", "FFS", 0.83, 1], ["6166432", "FFS", 0.43, 211], ["6166433", "FS", 1.0, 6], ["6166434", "FFS", 0.6, 161], ["6166435", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1]], "6166425": [["6166297", "FFS", 0.1, 1], ["6166298", "FFS", 0.1, 1], ["6166301", "FFS", 0.1, 1], ["6166303", "FFS", 0.1, 1], ["6166305", "FFS", 0.1, 1], ["6166309", "FFS", 0.1, 1], ["6166322", "FFS", 0.1, 1], ["6166336", "FFS", 0.1, 1], ["6166337", "FFS", 0.1, 1], ["6166338", "FFS", 0.1, 1], ["6166339", "FFS", 0.1, 1], ["6166340", "FFS", 0.1, 1], ["6166341", "FFS", 0.1, 1], ["6166342", "FFS", 0.1, 1], ["6166343", "FFS", 0.1, 1], ["6166344", "FFS", 0.1, 1], ["6166345", "FFS", 0.1, 1], ["6166346", "FFS", 0.1, 1], ["6166347", "FFS", 0.1, 1], ["6166353", "SS", 0.14, 1], ["6166360", "SS", 0.17, 2], ["6166362", "SS", 0.17, 2], ["6166393", "FS", 1.0, 2], ["6166394", "FS", 1.0, 2], ["6166398", "SS", 0.17, 2], ["6166399", "SS", 0.17, 2], ["6166401", "SS", 0.17, 1], ["6166402", "SS", 0.17, 2], ["6166403", "FS", 1.0, 1], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 1], ["6166407", "FS", 1.0, 2], ["6166408", "FS", 1.0, 2], ["6166422", "FS", 1.0, 2]], "6166426": [["6166297", "FFS", 0.1, 1], ["6166298", "FFS", 0.1, 1], ["6166301", "FFS", 0.1, 1], ["6166303", "FFS", 0.1, 1], ["6166305", "FFS", 0.1, 1], ["6166309", "FFS", 0.1, 1], ["6166322", "FFS", 0.1, 1], ["6166336", "FFS", 0.1, 1], ["6166337", "FFS", 0.1, 1], ["6166338", "FFS", 0.1, 1], ["6166339", "FFS", 0.1, 1], ["6166340", "FFS", 0.1, 1], ["6166341", "FFS", 0.1, 1], ["6166342", "FFS", 0.1, 1], ["6166343", "FFS", 0.1, 1], ["6166344", "FFS", 0.1, 1], ["6166345", "FFS", 0.1, 1], ["6166346", "FFS", 0.1, 1], ["6166347", "FFS", 0.1, 1], ["6166353", "SS", 0.14, 1], ["6166360", "SS", 0.17, 2], ["6166362", "SS", 0.17, 2], ["6166393", "FS", 1.0, 2], ["6166394", "FS", 1.0, 2], ["6166398", "SS", 0.17, 2], ["6166399", "SS", 0.17, 2], ["6166401", "SS", 0.17, 1], ["6166402", "SS", 0.17, 2], ["6166403", "FS", 1.0, 1], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 1], ["6166407", "FS", 1.0, 2], ["6166408", "FS", 1.0, 2], ["6166422", "FS", 1.0, 2]], "6166431": [["6166295", "FS", 1.0, 14], ["6166296", "FFS", 0.25, 16], ["6166297", "FFS", 0.25, 11], ["6166298", "FFS", 0.25, 11], ["6166300", "FS", 1.0, 2], ["6166301", "FFS", 0.25, 11], ["6166302", "FS", 1.0, 1], ["6166303", "FFS", 0.25, 11], ["6166305", "FFS", 0.25, 11], ["6166309", "FFS", 0.25, 11], ["6166316", "FFS", 0.2, 12], ["6166319", "FFS", 0.2, 12], ["6166322", "FFS", 0.25, 11], ["6166323", "FFS", 0.25, 16], ["6166332", "FFS", 0.2, 12], ["6166333", "FFS", 0.2, 12], ["6166334", "FS", 1.0, 8], ["6166335", "FFS", 0.2, 12], ["6166336", "FFS", 0.25, 11], ["6166337", "FFS", 0.25, 11], ["6166338", "FFS", 0.25, 11], ["6166339", "FFS", 0.25, 11], ["6166340", "FFS", 0.25, 11], ["6166341", "FFS", 0.25, 11], ["6166342", "FFS", 0.25, 11], ["6166343", "FFS", 0.25, 11], ["6166344", "FFS", 0.25, 11], ["6166345", "FFS", 0.25, 11], ["6166346", "FFS", 0.25, 11], ["6166347", "FFS", 0.25, 11], ["6166348", "FS", 1.0, 5], ["6166349", "FS", 1.0, 5], ["6166350", "FS", 1.0, 5], ["6166351", "FS", 1.0, 2], ["6166352", "FS", 1.0, 2], ["6166353", "FFS", 0.01, 177], ["6166354", "FS", 1.0, 5], ["6166355", "FS", 1.0, 5], ["6166356", "FS", 1.0, 2], ["6166357", "FS", 1.0, 5], ["6166358", "FS", 1.0, 5], ["6166360", "FS", 1.0, 3], ["6166362", "FS", 1.0, 3], ["6166368", "FFS", 0.25, 16], ["6166369", "FFS", 0.25, 16], ["6166383", "FS", 1.0, 5], ["6166390", "FS", 1.0, 14], ["6166393", "FFS", 0.95, 2], ["6166394", "FFS", 0.95, 2], ["6166396", "FFS", 0.01, 58], ["6166398", "FS", 1.0, 3], ["6166399", "FS", 1.0, 3], ["6166400", "FS", 1.0, 14], ["6166402", "FS", 1.0, 3], ["6166403", "FFS", 0.71, 1], ["6166405", "FFS", 0.71, 1], ["6166407", "FFS", 0.95, 2], ["6166408", "FFS", 0.55, 3], ["6166410", "FS", 1.0, 1], ["6166412", "FS", 1.0, 8], ["6166413", "FS", 1.0, 8], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166418", "FS", 1.0, 8], ["6166419", "FS", 1.0, 8], ["6166420", "FS", 1.0, 8], ["6166422", "FFS", 0.08, 5], ["6166424", "FFS", 0.01, 134], ["6166432", "FFS", 0.18, 322], ["6166433", "FFS", 0.17, 53], ["6166434", "FFS", 0.03, 368], ["9350109", "FS", 1.0, 1], ["15643783", "FS", 1.0, 16], ["15643796", "FS", 1.0, 16], ["15659698", "FS", 1.0, 16], ["15659699", "FS", 1.0, 16], ["15659700", "FS", 1.0, 16], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "6166432": [["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166404", "FS", 1.0, 2], ["6166407", "FS", 1.0, 1], ["6166422", "FFS", 0.5, 2], ["6166434", "FFS", 0.04, 1235], ["6166435", "FFS", 0.06, 104]], "6166433": [["6166403", "SS", 0.28, 3], ["6166405", "SS", 0.28, 3], ["6166432", "FFS", 0.01, 39], ["6166434", "FFS", 0.83, 42], ["6166435", "FS", 1.0, 23]], "6166434": [["6166411", "FS", 1.0, 1], ["16345501", "FS", 1.0, 1], ["16345502", "FS", 1.0, 1], ["16345503", "FS", 1.0, 1], ["16345504", "FS", 1.0, 1], ["16345505", "FS", 1.0, 1], ["16345506", "FS", 1.0, 1], ["17663819", "FS", 1.0, 1], ["17663847", "FS", 1.0, 1]], "6166435": [["6166431", "FFS", 0.01, 180], ["6166434", "FFS", 0.01, 263]], "7403036": [], "7403037": [], "7403038": [], "7403039": [], "8867825": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166307", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1]], "8923101": [["6166396", "FS", 1.0, 1], ["6166422", "FS", 1.0, 1], ["6166424", "FS", 1.0, 1], ["6166434", "FS", 1.0, 2]], "9071017": [], "9350109": [["6166393", "SS", 0.05, 1], ["6166394", "SS", 0.05, 1], ["6166407", "SS", 0.05, 1]], "15643783": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FFS", 0.01, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166398", "FFS", 0.01, 20], ["6166399", "FFS", 0.01, 20], ["6166400", "FFS", 0.01, 37], ["6166402", "FFS", 0.01, 20], ["6166403", "FS", 1.0, 6], ["6166405", "FS", 1.0, 6], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.01, 18], ["6166411", "FFS", 0.88, 12], ["6166412", "SS", 0.46, 2], ["6166413", "SS", 0.46, 2], ["6166418", "SS", 0.46, 2], ["6166419", "SS", 0.46, 2], ["6166420", "SS", 0.46, 2], ["6166422", "FFS", 0.01, 10], ["6166424", "FFS", 0.01, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FFS", 0.01, 5], ["6166434", "FFS", 0.01, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "15643794": [], "15643796": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FFS", 0.01, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166398", "FFS", 0.01, 20], ["6166399", "FFS", 0.01, 20], ["6166400", "FFS", 0.01, 37], ["6166402", "FFS", 0.01, 20], ["6166403", "FS", 1.0, 6], ["6166405", "FS", 1.0, 6], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.01, 18], ["6166411", "FFS", 0.88, 12], ["6166412", "SS", 0.46, 2], ["6166413", "SS", 0.46, 2], ["6166418", "SS", 0.46, 2], ["6166419", "SS", 0.46, 2], ["6166420", "SS", 0.46, 2], ["6166422", "FFS", 0.01, 10], ["6166424", "FFS", 0.01, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FFS", 0.01, 5], ["6166434", "FFS", 0.01, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "15659698": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FFS", 0.01, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166398", "FFS", 0.01, 20], ["6166399", "FFS", 0.01, 20], ["6166400", "FFS", 0.01, 37], ["6166402", "FFS", 0.01, 20], ["6166403", "FS", 1.0, 6], ["6166405", "FS", 1.0, 6], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.01, 18], ["6166411", "FFS", 0.88, 12], ["6166412", "SS", 0.46, 2], ["6166413", "SS", 0.46, 2], ["6166418", "SS", 0.46, 2], ["6166419", "SS", 0.46, 2], ["6166420", "SS", 0.46, 2], ["6166422", "FFS", 0.01, 10], ["6166424", "FFS", 0.01, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FFS", 0.01, 5], ["6166434", "FFS", 0.01, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "15659699": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FFS", 0.01, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166398", "FFS", 0.01, 20], ["6166399", "FFS", 0.01, 20], ["6166400", "FFS", 0.01, 37], ["6166402", "FFS", 0.01, 20], ["6166403", "FS", 1.0, 6], ["6166405", "FS", 1.0, 6], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.01, 18], ["6166411", "FFS", 0.88, 12], ["6166412", "SS", 0.46, 2], ["6166413", "SS", 0.46, 2], ["6166418", "SS", 0.46, 2], ["6166419", "SS", 0.46, 2], ["6166420", "SS", 0.46, 2], ["6166422", "FFS", 0.01, 10], ["6166424", "FFS", 0.01, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FFS", 0.01, 5], ["6166434", "FFS", 0.01, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "15659700": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FFS", 0.01, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166398", "FFS", 0.01, 20], ["6166399", "FFS", 0.01, 20], ["6166400", "FFS", 0.01, 37], ["6166402", "FFS", 0.01, 20], ["6166403", "FS", 1.0, 6], ["6166405", "FS", 1.0, 6], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.01, 18], ["6166411", "FFS", 0.88, 12], ["6166412", "SS", 0.46, 2], ["6166413", "SS", 0.46, 2], ["6166418", "SS", 0.46, 2], ["6166419", "SS", 0.46, 2], ["6166420", "SS", 0.46, 2], ["6166422", "FFS", 0.01, 10], ["6166424", "FFS", 0.01, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FFS", 0.01, 5], ["6166434", "FFS", 0.01, 6], ["16147472", "FFS", 0.38, 85], ["16147473", "FFS", 0.38, 85], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "16147472": [["6166292", "FFS", 0.01, 23], ["6166293", "FFS", 0.23, 15], ["6166294", "FFS", 0.23, 15], ["6166295", "FFS", 0.3, 38], ["6166297", "FFS", 0.01, 118], ["6166298", "FFS", 0.01, 118], ["6166299", "FS", 1.0, 2], ["6166301", "FFS", 0.01, 118], ["6166303", "FFS", 0.01, 118], ["6166305", "FFS", 0.01, 118], ["6166309", "FFS", 0.01, 118], ["6166316", "FFS", 0.01, 25], ["6166319", "FFS", 0.01, 25], ["6166322", "FFS", 0.01, 118], ["6166324", "FFS", 0.4, 1], ["6166332", "FFS", 0.01, 25], ["6166333", "FFS", 0.01, 25], ["6166334", "FS", 1.0, 8], ["6166335", "FFS", 0.01, 25], ["6166336", "FFS", 0.01, 118], ["6166337", "FFS", 0.01, 118], ["6166338", "FFS", 0.01, 118], ["6166339", "FFS", 0.01, 118], ["6166340", "FFS", 0.01, 118], ["6166341", "FFS", 0.01, 118], ["6166342", "FFS", 0.01, 118], ["6166343", "FFS", 0.01, 118], ["6166344", "FFS", 0.01, 118], ["6166345", "FFS", 0.01, 118], ["6166346", "FFS", 0.01, 118], ["6166347", "FFS", 0.01, 118], ["6166353", "FFS", 0.01, 35], ["6166390", "FFS", 0.3, 38], ["6166396", "FS", 1.0, 2], ["6166400", "FFS", 0.3, 38], ["6166403", "FS", 1.0, 2], ["6166404", "FS", 1.0, 2], ["6166405", "FS", 1.0, 2], ["6166412", "FS", 1.0, 8], ["6166413", "FS", 1.0, 8], ["6166418", "FS", 1.0, 8], ["6166419", "FS", 1.0, 8], ["6166420", "FS", 1.0, 8], ["6166422", "FS", 1.0, 4], ["6166424", "FFS", 0.01, 10], ["6166431", "FS", 1.0, 4], ["6166432", "FS", 1.0, 9], ["6166434", "FFS", 0.4, 10]], "16147473": [["6166292", "FFS", 0.01, 23], ["6166293", "FFS", 0.23, 15], ["6166294", "FFS", 0.23, 15], ["6166295", "FFS", 0.3, 38], ["6166297", "FFS", 0.01, 118], ["6166298", "FFS", 0.01, 118], ["6166299", "FS", 1.0, 2], ["6166301", "FFS", 0.01, 118], ["6166303", "FFS", 0.01, 118], ["6166305", "FFS", 0.01, 118], ["6166309", "FFS", 0.01, 118], ["6166316", "FFS", 0.01, 25], ["6166319", "FFS", 0.01, 25], ["6166322", "FFS", 0.01, 118], ["6166324", "FFS", 0.4, 1], ["6166332", "FFS", 0.01, 25], ["6166333", "FFS", 0.01, 25], ["6166334", "FS", 1.0, 8], ["6166335", "FFS", 0.01, 25], ["6166336", "FFS", 0.01, 118], ["6166337", "FFS", 0.01, 118], ["6166338", "FFS", 0.01, 118], ["6166339", "FFS", 0.01, 118], ["6166340", "FFS", 0.01, 118], ["6166341", "FFS", 0.01, 118], ["6166342", "FFS", 0.01, 118], ["6166343", "FFS", 0.01, 118], ["6166344", "FFS", 0.01, 118], ["6166345", "FFS", 0.01, 118], ["6166346", "FFS", 0.01, 118], ["6166347", "FFS", 0.01, 118], ["6166353", "FFS", 0.01, 35], ["6166390", "FFS", 0.3, 38], ["6166396", "FS", 1.0, 2], ["6166400", "FFS", 0.3, 38], ["6166403", "FS", 1.0, 2], ["6166404", "FS", 1.0, 2], ["6166405", "FS", 1.0, 2], ["6166412", "FS", 1.0, 8], ["6166413", "FS", 1.0, 8], ["6166418", "FS", 1.0, 8], ["6166419", "FS", 1.0, 8], ["6166420", "FS", 1.0, 8], ["6166422", "FS", 1.0, 4], ["6166424", "FFS", 0.01, 10], ["6166431", "FS", 1.0, 4], ["6166432", "FS", 1.0, 9], ["6166434", "FFS", 0.4, 10]], "16147476": [["6166292", "FFS", 0.01, 3], ["16147472", "SS", 0.93, 3], ["16147473", "SS", 0.93, 3]], "16147477": [["6166293", "FS", 1.0, 3], ["6166294", "FS", 1.0, 3], ["6166296", "FFS", 0.01, 5], ["6166297", "FFS", 0.01, 4], ["6166298", "FFS", 0.01, 4], ["6166300", "FFS", 0.01, 2], ["6166301", "FFS", 0.01, 4], ["6166302", "FS", 1.0, 2], ["6166303", "FFS", 0.01, 4], ["6166305", "FFS", 0.01, 4], ["6166309", "FFS", 0.01, 4], ["6166322", "FFS", 0.01, 4], ["6166323", "FFS", 0.01, 5], ["6166336", "FFS", 0.01, 4], ["6166337", "FFS", 0.01, 4], ["6166338", "FFS", 0.01, 4], ["6166339", "FFS", 0.01, 4], ["6166340", "FFS", 0.01, 4], ["6166341", "FFS", 0.01, 4], ["6166342", "FFS", 0.01, 4], ["6166343", "FFS", 0.01, 4], ["6166344", "FFS", 0.01, 4], ["6166345", "FFS", 0.01, 4], ["6166346", "FFS", 0.01, 4], ["6166347", "FFS", 0.01, 4], ["6166351", "FFS", 0.01, 2], ["6166352", "FFS", 0.01, 2], ["6166356", "FFS", 0.01, 2], ["6166368", "FFS", 0.01, 5], ["6166369", "FFS", 0.01, 5], ["15643783", "FFS", 0.01, 5], ["15643796", "FFS", 0.01, 5], ["15659698", "FFS", 0.01, 5], ["15659699", "FFS", 0.01, 5], ["15659700", "FFS", 0.01, 5], ["16147472", "FFS", 0.01, 23], ["16147473", "FFS", 0.01, 23], ["16147476", "FFS", 0.01, 3]], "16345501": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166424", "FFS", 1.0, 6], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.01, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17502319", "FFS", 0.5, 17], ["17502544", "FFS", 0.5, 17]], "16345502": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166424", "FFS", 1.0, 6], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.01, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17502319", "FFS", 0.5, 17], ["17502544", "FFS", 0.5, 17]], "16345503": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166424", "FFS", 1.0, 6], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.01, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17502319", "FFS", 0.5, 17], ["17502544", "FFS", 0.5, 17]], "16345504": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166424", "FFS", 1.0, 6], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.01, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17502319", "FFS", 0.5, 17], ["17502544", "FFS", 0.5, 17]], "16345505": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166424", "FFS", 1.0, 6], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.01, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17502319", "FFS", 0.5, 17], ["17502544", "FFS", 0.5, 17]], "16345506": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166424", "FFS", 1.0, 6], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.01, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17502319", "FFS", 0.5, 17], ["17502544", "FFS", 0.5, 17]], "17240028": [["6166295", "FS", 1.0, 1], ["6166296", "FFS", 1.0, 5], ["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166323", "FFS", 1.0, 5], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166368", "FFS", 1.0, 5], ["6166369", "FFS", 1.0, 5], ["6166390", "FS", 1.0, 1], ["6166400", "FS", 1.0, 1], ["6166404", "FFS", 0.97, 1], ["6166411", "FS", 1.0, 8], ["6166431", "FS", 1.0, 13], ["6166432", "FS", 1.0, 1], ["15643783", "FFS", 1.0, 5], ["15643796", "FFS", 1.0, 5], ["15659698", "FFS", 1.0, 5], ["15659699", "FFS", 1.0, 5], ["15659700", "FFS", 1.0, 5], ["16345501", "FS", 1.0, 8], ["16345502", "FS", 1.0, 8], ["16345503", "FS", 1.0, 8], ["16345504", "FS", 1.0, 8], ["16345505", "FS", 1.0, 8], ["16345506", "FS", 1.0, 8], ["17502319", "FS", 1.0, 13], ["17502544", "FS", 1.0, 13]], "17240031": [["6166295", "FS", 1.0, 1], ["6166296", "FFS", 1.0, 5], ["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166323", "FFS", 1.0, 5], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166368", "FFS", 1.0, 5], ["6166369", "FFS", 1.0, 5], ["6166390", "FS", 1.0, 1], ["6166400", "FS", 1.0, 1], ["6166404", "FFS", 0.97, 1], ["6166411", "FS", 1.0, 8], ["6166431", "FS", 1.0, 13], ["6166432", "FS", 1.0, 1], ["15643783", "FFS", 1.0, 5], ["15643796", "FFS", 1.0, 5], ["15659698", "FFS", 1.0, 5], ["15659699", "FFS", 1.0, 5], ["15659700", "FFS", 1.0, 5], ["16345501", "FS", 1.0, 8], ["16345502", "FS", 1.0, 8], ["16345503", "FS", 1.0, 8], ["16345504", "FS", 1.0, 8], ["16345505", "FS", 1.0, 8], ["16345506", "FS", 1.0, 8], ["17502319", "FS", 1.0, 13], ["17502544", "FS", 1.0, 13]], "17240032": [["6166295", "FS", 1.0, 1], ["6166296", "FFS", 1.0, 5], ["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166323", "FFS", 1.0, 5], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166368", "FFS", 1.0, 5], ["6166369", "FFS", 1.0, 5], ["6166390", "FS", 1.0, 1], ["6166400", "FS", 1.0, 1], ["6166404", "FFS", 0.97, 1], ["6166411", "FS", 1.0, 8], ["6166431", "FS", 1.0, 13], ["6166432", "FS", 1.0, 1], ["15643783", "FFS", 1.0, 5], ["15643796", "FFS", 1.0, 5], ["15659698", "FFS", 1.0, 5], ["15659699", "FFS", 1.0, 5], ["15659700", "FFS", 1.0, 5], ["16345501", "FS", 1.0, 8], ["16345502", "FS", 1.0, 8], ["16345503", "FS", 1.0, 8], ["16345504", "FS", 1.0, 8], ["16345505", "FS", 1.0, 8], ["16345506", "FS", 1.0, 8], ["17502319", "FS", 1.0, 13], ["17502544", "FS", 1.0, 13]], "17502319": [["6166295", "FS", 1.0, 14], ["6166296", "FFS", 0.25, 16], ["6166297", "FFS", 0.25, 11], ["6166298", "FFS", 0.25, 11], ["6166300", "FS", 1.0, 2], ["6166301", "FFS", 0.25, 11], ["6166302", "FS", 1.0, 1], ["6166303", "FFS", 0.25, 11], ["6166305", "FFS", 0.25, 11], ["6166309", "FFS", 0.25, 11], ["6166316", "FFS", 0.2, 12], ["6166319", "FFS", 0.2, 12], ["6166322", "FFS", 0.25, 11], ["6166323", "FFS", 0.25, 16], ["6166332", "FFS", 0.2, 12], ["6166333", "FFS", 0.2, 12], ["6166334", "FS", 1.0, 8], ["6166335", "FFS", 0.2, 12], ["6166336", "FFS", 0.25, 11], ["6166337", "FFS", 0.25, 11], ["6166338", "FFS", 0.25, 11], ["6166339", "FFS", 0.25, 11], ["6166340", "FFS", 0.25, 11], ["6166341", "FFS", 0.25, 11], ["6166342", "FFS", 0.25, 11], ["6166343", "FFS", 0.25, 11], ["6166344", "FFS", 0.25, 11], ["6166345", "FFS", 0.25, 11], ["6166346", "FFS", 0.25, 11], ["6166347", "FFS", 0.25, 11], ["6166348", "FS", 1.0, 5], ["6166349", "FS", 1.0, 5], ["6166350", "FS", 1.0, 5], ["6166351", "FS", 1.0, 2], ["6166352", "FS", 1.0, 2], ["6166353", "FFS", 0.01, 177], ["6166354", "FS", 1.0, 5], ["6166355", "FS", 1.0, 5], ["6166356", "FS", 1.0, 2], ["6166357", "FS", 1.0, 5], ["6166358", "FS", 1.0, 5], ["6166360", "FS", 1.0, 3], ["6166362", "FS", 1.0, 3], ["6166368", "FFS", 0.25, 16], ["6166369", "FFS", 0.25, 16], ["6166383", "FS", 1.0, 5], ["6166390", "FS", 1.0, 14], ["6166393", "FFS", 0.95, 2], ["6166394", "FFS", 0.95, 2], ["6166396", "FFS", 0.01, 58], ["6166398", "FS", 1.0, 3], ["6166399", "FS", 1.0, 3], ["6166400", "FS", 1.0, 14], ["6166402", "FS", 1.0, 3], ["6166403", "FFS", 0.71, 1], ["6166405", "FFS", 0.71, 1], ["6166407", "FFS", 0.95, 2], ["6166408", "FFS", 0.55, 3], ["6166410", "FS", 1.0, 1], ["6166412", "FS", 1.0, 8], ["6166413", "FS", 1.0, 8], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166418", "FS", 1.0, 8], ["6166419", "FS", 1.0, 8], ["6166420", "FS", 1.0, 8], ["6166422", "FFS", 0.08, 5], ["6166424", "FFS", 0.01, 134], ["6166432", "FFS", 0.01, 322], ["6166433", "FFS", 0.01, 53], ["6166434", "FFS", 0.01, 368], ["6166435", "FFS", 0.01, 180], ["9350109", "FS", 1.0, 1], ["15643783", "FFS", 0.25, 16], ["15643796", "FFS", 0.25, 16], ["15659698", "FFS", 0.25, 16], ["15659699", "FFS", 0.25, 16], ["15659700", "FFS", 0.25, 16], ["16147472", "FS", 1.0, 4], ["16147473", "FS", 1.0, 4], ["17502541", "FS", 1.0, 16], ["17502543", "FS", 1.0, 16], ["17502545", "FS", 1.0, 16]], "17502541": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FFS", 0.01, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166398", "FFS", 0.01, 20], ["6166399", "FFS", 0.01, 20], ["6166400", "FFS", 0.01, 37], ["6166402", "FFS", 0.01, 20], ["6166403", "FS", 1.0, 6], ["6166405", "FS", 1.0, 6], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.01, 18], ["6166411", "FFS", 0.88, 12], ["6166412", "SS", 0.46, 2], ["6166413", "SS", 0.46, 2], ["6166418", "SS", 0.46, 2], ["6166419", "SS", 0.46, 2], ["6166420", "SS", 0.46, 2], ["6166422", "FFS", 0.01, 10], ["6166424", "FFS", 0.01, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FFS", 0.01, 5], ["6166434", "FFS", 0.01, 6], ["16147472", "FFS", 0.01, 85], ["16147473", "FFS", 0.01, 85], ["16147477", "FFS", 0.01, 5], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17240028", "SS", 0.33, 5], ["17240031", "SS", 0.33, 5], ["17240032", "SS", 0.33, 5], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "17502543": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FFS", 0.01, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166398", "FFS", 0.01, 20], ["6166399", "FFS", 0.01, 20], ["6166400", "FFS", 0.01, 37], ["6166402", "FFS", 0.01, 20], ["6166403", "FS", 1.0, 6], ["6166405", "FS", 1.0, 6], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.01, 18], ["6166411", "FFS", 0.88, 12], ["6166412", "SS", 0.46, 2], ["6166413", "SS", 0.46, 2], ["6166418", "SS", 0.46, 2], ["6166419", "SS", 0.46, 2], ["6166420", "SS", 0.46, 2], ["6166422", "FFS", 0.01, 10], ["6166424", "FFS", 0.01, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FFS", 0.01, 5], ["6166434", "FFS", 0.01, 6], ["16147472", "FFS", 0.01, 85], ["16147473", "FFS", 0.01, 85], ["16147477", "FFS", 0.01, 5], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17240028", "SS", 0.33, 5], ["17240031", "SS", 0.33, 5], ["17240032", "SS", 0.33, 5], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "17502544": [["6166295", "FS", 1.0, 14], ["6166296", "FFS", 0.25, 16], ["6166297", "FFS", 0.25, 11], ["6166298", "FFS", 0.25, 11], ["6166300", "FS", 1.0, 2], ["6166301", "FFS", 0.25, 11], ["6166302", "FS", 1.0, 1], ["6166303", "FFS", 0.25, 11], ["6166305", "FFS", 0.25, 11], ["6166309", "FFS", 0.25, 11], ["6166316", "FFS", 0.2, 12], ["6166319", "FFS", 0.2, 12], ["6166322", "FFS", 0.25, 11], ["6166323", "FFS", 0.25, 16], ["6166332", "FFS", 0.2, 12], ["6166333", "FFS", 0.2, 12], ["6166334", "FS", 1.0, 8], ["6166335", "FFS", 0.2, 12], ["6166336", "FFS", 0.25, 11], ["6166337", "FFS", 0.25, 11], ["6166338", "FFS", 0.25, 11], ["6166339", "FFS", 0.25, 11], ["6166340", "FFS", 0.25, 11], ["6166341", "FFS", 0.25, 11], ["6166342", "FFS", 0.25, 11], ["6166343", "FFS", 0.25, 11], ["6166344", "FFS", 0.25, 11], ["6166345", "FFS", 0.25, 11], ["6166346", "FFS", 0.25, 11], ["6166347", "FFS", 0.25, 11], ["6166348", "FS", 1.0, 5], ["6166349", "FS", 1.0, 5], ["6166350", "FS", 1.0, 5], ["6166351", "FS", 1.0, 2], ["6166352", "FS", 1.0, 2], ["6166353", "FFS", 0.01, 177], ["6166354", "FS", 1.0, 5], ["6166355", "FS", 1.0, 5], ["6166356", "FS", 1.0, 2], ["6166357", "FS", 1.0, 5], ["6166358", "FS", 1.0, 5], ["6166360", "FS", 1.0, 3], ["6166362", "FS", 1.0, 3], ["6166368", "FFS", 0.25, 16], ["6166369", "FFS", 0.25, 16], ["6166383", "FS", 1.0, 5], ["6166390", "FS", 1.0, 14], ["6166393", "FFS", 0.95, 2], ["6166394", "FFS", 0.95, 2], ["6166396", "FFS", 0.01, 58], ["6166398", "FS", 1.0, 3], ["6166399", "FS", 1.0, 3], ["6166400", "FS", 1.0, 14], ["6166402", "FS", 1.0, 3], ["6166403", "FFS", 0.71, 1], ["6166405", "FFS", 0.71, 1], ["6166407", "FFS", 0.95, 2], ["6166408", "FFS", 0.55, 3], ["6166410", "FS", 1.0, 1], ["6166412", "FS", 1.0, 8], ["6166413", "FS", 1.0, 8], ["6166415", "FS", 1.0, 2], ["6166417", "FS", 1.0, 2], ["6166418", "FS", 1.0, 8], ["6166419", "FS", 1.0, 8], ["6166420", "FS", 1.0, 8], ["6166422", "FFS", 0.08, 5], ["6166424", "FFS", 0.01, 134], ["6166432", "FFS", 0.01, 322], ["6166433", "FFS", 0.01, 53], ["6166434", "FFS", 0.01, 368], ["6166435", "FFS", 0.01, 180], ["9350109", "FS", 1.0, 1], ["15643783", "FFS", 0.25, 16], ["15643796", "FFS", 0.25, 16], ["15659698", "FFS", 0.25, 16], ["15659699", "FFS", 0.25, 16], ["15659700", "FFS", 0.25, 16], ["16147472", "FS", 1.0, 4], ["16147473", "FS", 1.0, 4], ["17502541", "FFS", 0.25, 16], ["17502543", "FFS", 0.25, 16], ["17502545", "FS", 1.0, 16]], "17502545": [["6166292", "FFS", 0.01, 5], ["6166293", "FFS", 0.01, 13], ["6166294", "FFS", 0.01, 13], ["6166295", "FFS", 0.01, 37], ["6166297", "FFS", 0.01, 60], ["6166298", "FFS", 0.01, 60], ["6166299", "FS", 1.0, 2], ["6166300", "FFS", 0.01, 18], ["6166301", "FFS", 0.01, 60], ["6166302", "FFS", 0.01, 3], ["6166303", "FFS", 0.01, 60], ["6166304", "FS", 1.0, 1], ["6166305", "FFS", 0.01, 60], ["6166308", "FS", 1.0, 1], ["6166309", "FFS", 0.01, 60], ["6166316", "FFS", 0.01, 102], ["6166319", "FFS", 0.01, 102], ["6166322", "FFS", 0.01, 60], ["6166332", "FFS", 0.01, 102], ["6166333", "FFS", 0.01, 102], ["6166334", "SS", 0.46, 2], ["6166335", "FFS", 0.01, 102], ["6166336", "FFS", 0.01, 60], ["6166337", "FFS", 0.01, 60], ["6166338", "FFS", 0.01, 60], ["6166339", "FFS", 0.01, 60], ["6166340", "FFS", 0.01, 60], ["6166341", "FFS", 0.01, 60], ["6166342", "FFS", 0.01, 60], ["6166343", "FFS", 0.01, 60], ["6166344", "FFS", 0.01, 60], ["6166345", "FFS", 0.01, 60], ["6166346", "FFS", 0.01, 60], ["6166347", "FFS", 0.01, 60], ["6166351", "FFS", 0.01, 18], ["6166352", "FFS", 0.01, 18], ["6166353", "FFS", 0.01, 48], ["6166356", "FFS", 0.01, 18], ["6166360", "FFS", 0.01, 20], ["6166362", "FFS", 0.01, 20], ["6166364", "FFS", 0.01, 8], ["6166366", "FFS", 0.01, 2], ["6166367", "FFS", 0.01, 8], ["6166390", "FFS", 0.01, 37], ["6166393", "FS", 1.0, 1], ["6166394", "FS", 1.0, 1], ["6166396", "FFS", 0.1, 8], ["6166397", "FS", 1.0, 1], ["6166398", "FFS", 0.01, 20], ["6166399", "FFS", 0.01, 20], ["6166400", "FFS", 0.01, 37], ["6166402", "FFS", 0.01, 20], ["6166403", "FS", 1.0, 6], ["6166405", "FS", 1.0, 6], ["6166407", "FS", 1.0, 1], ["6166408", "FFS", 0.01, 18], ["6166411", "FFS", 0.88, 12], ["6166412", "SS", 0.46, 2], ["6166413", "SS", 0.46, 2], ["6166418", "SS", 0.46, 2], ["6166419", "SS", 0.46, 2], ["6166420", "SS", 0.46, 2], ["6166422", "FFS", 0.01, 10], ["6166424", "FFS", 0.01, 26], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166432", "FS", 1.0, 3], ["6166433", "FFS", 0.01, 5], ["6166434", "FFS", 0.01, 6], ["16147472", "FFS", 0.01, 85], ["16147473", "FFS", 0.01, 85], ["16147477", "FFS", 0.01, 5], ["16345501", "FFS", 0.88, 12], ["16345502", "FFS", 0.88, 12], ["16345503", "FFS", 0.88, 12], ["16345504", "FFS", 0.88, 12], ["16345505", "FFS", 0.88, 12], ["16345506", "FFS", 0.88, 12], ["17240028", "SS", 0.33, 5], ["17240031", "SS", 0.33, 5], ["17240032", "SS", 0.33, 5], ["17663819", "FFS", 0.88, 12], ["17663847", "FFS", 0.88, 12]], "17663819": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166424", "FFS", 1.0, 6], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.01, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17240028", "FFS", 0.67, 8], ["17240031", "FFS", 0.67, 8], ["17240032", "FFS", 0.67, 8], ["17502319", "FFS", 0.01, 17], ["17502544", "FFS", 0.01, 17]], "17663847": [["6166297", "FS", 1.0, 1], ["6166298", "FS", 1.0, 1], ["6166301", "FS", 1.0, 1], ["6166303", "FS", 1.0, 1], ["6166305", "FS", 1.0, 1], ["6166309", "FS", 1.0, 1], ["6166322", "FS", 1.0, 1], ["6166336", "FS", 1.0, 1], ["6166337", "FS", 1.0, 1], ["6166338", "FS", 1.0, 1], ["6166339", "FS", 1.0, 1], ["6166340", "FS", 1.0, 1], ["6166341", "FS", 1.0, 1], ["6166342", "FS", 1.0, 1], ["6166343", "FS", 1.0, 1], ["6166344", "FS", 1.0, 1], ["6166345", "FS", 1.0, 1], ["6166346", "FS", 1.0, 1], ["6166347", "FS", 1.0, 1], ["6166353", "FFS", 0.01, 4], ["6166393", "FFS", 0.67, 2], ["6166394", "FFS", 0.67, 2], ["6166395", "FFS", 0.65, 1], ["6166396", "FS", 1.0, 1], ["6166397", "FS", 1.0, 1], ["6166403", "FS", 1.0, 4], ["6166404", "FS", 1.0, 4], ["6166405", "FS", 1.0, 4], ["6166407", "FFS", 0.67, 2], ["6166408", "FFS", 0.01, 33], ["6166409", "FFS", 0.25, 2], ["6166424", "FFS", 1.0, 6], ["6166425", "FS", 1.0, 1], ["6166426", "FS", 1.0, 1], ["6166431", "FFS", 0.01, 17], ["6166433", "FS", 1.0, 1], ["9350109", "FS", 1.0, 1], ["17240028", "FFS", 0.67, 8], ["17240031", "FFS", 0.67, 8], ["17240032", "FFS", 0.67, 8], ["17502319", "FFS", 0.01, 17], ["17502544", "FFS", 0.01, 17]]}

    gas_network.update(electroline)
    gas_network.update(dormitory)
    connections_dict = gas_network

    predecessors_ids_lst, predecessors_types_lst, predecessors_lags_lst, predecessors_counts_lst = [], [], [], []

    for task_id, pred_info_lst in connections_dict.items():
        if str(task_id) not in tasks_df.index:
            continue

        row = tasks_df.loc[str(task_id)]

        # | ------ change links and info about them ------ |
        # by default, the links and their information change
        if len(pred_info_lst) > 0:
            pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst = map(list, zip(*pred_info_lst))
        else:
            pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst = ['-1'], ['-1'], [1.0], [0]

        if not all_connections:
            pred_ids_lst_tmp, pred_types_lst_tmp, pred_lags_lst_tmp, pred_counts_lst_tmp = (
                row['predecessor_ids'].copy(), row['connection_types'].copy(), row['lags'].copy(), [math.nan] * len(row['lags']))
            if change_connections_info:
                pred_ids_lst_tmp, pred_types_lst_tmp, pred_lags_lst_tmp, pred_counts_lst_tmp = (
                    update_connections(pred_ids_lst_tmp, pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst))
            pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst = (
                append_new_connections(pred_ids_lst_tmp, pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst))
        else:
            if row['predecessor_ids'] != ['-1']:
                # if 'lags' is unknown, thus 'connection_type' is also unknown
                pred_info_lst = [[pred_types_lst[i], pred_lags_lst[i], pred_counts_lst[i]]
                                 for i in range(len(pred_ids_lst)) if pred_ids_lst[i] in row['predecessor_ids']]
                pred_ids_lst = row['predecessor_ids']
                if len(pred_info_lst) > 0:
                    pred_types_lst, pred_lags_lst, pred_counts_lst = map(list, zip(*pred_info_lst))
                else:
                    pred_types_lst, pred_lags_lst, pred_counts_lst = ['-1'], [1.0], [0]

        predecessors_ids_lst.append(pred_ids_lst)
        predecessors_types_lst.append(pred_types_lst)
        predecessors_lags_lst.append(pred_lags_lst)
        predecessors_counts_lst.append(pred_counts_lst)
        while len(predecessors_types_lst[-1]) != len(predecessors_ids_lst[-1]):
            predecessors_types_lst[-1].append('FS')
            predecessors_lags_lst[-1].append(1.0)
            predecessors_counts_lst[-1].append(0)

    # Convert strings to arrays
    tasks_df['predecessor_ids'] = predecessors_ids_lst
    tasks_df['connection_types'] = predecessors_types_lst
    tasks_df['lags'] = predecessors_lags_lst
    tasks_df['counts'] = predecessors_counts_lst

    tasks_df['connection_types'] = tasks_df['connection_types'].apply(
        lambda x: [EdgeType(elem) if elem != '-1' else EdgeType.FinishStart for elem in x]
    )

    return tasks_df
